
clear; 

% Set Random number generator seed to the same value- generates tables
% identical to those reported. If you keep this code in and use 100000 finite
% sample simulations, the table output will be identical 
randn('state',0); 

% Set Parameters and Load Data
load Annual_Data.txt;
load Quarterly_Data.txt; 
load quart_year_data.txt; 

% Number of Finite Sample Simulations
simnum=100000;


% Data Manipulation 
cons=Annual_Data(:,1); div=Annual_Data(:,2); pd=Annual_Data(:,3); ret=Annual_Data(:,4); rf=Annual_Data(:,5); exret=ret-rf; 
cons_q=Quarterly_Data(:,1); div_q=Quarterly_Data(:,2); pd_q=Quarterly_Data(:,3); ret_q=Quarterly_Data(:,4); rf_q=Quarterly_Data(:,5); exret_q=ret_q-rf_q; 
cons_q_ann=quart_year_data(:,1); div_q_ann=quart_year_data(:,2); 
[T K]=size(Annual_Data); 
[T_q K_q]=size(Quarterly_Data); 
yearly_months=T*12; 
quarterly_months=T_q*3; 

% Basic Data Moments Yearly Data
moment_mat_y=[100*mean(cons) 100*std(cons) ACC(cons,1); 100*mean(div) 100*std(div) ACC(div,1);100*mean(ret) 100*std(ret) ACC(ret,1); 100*mean(rf) 100*std(rf) ...
    ACC(rf,1); mean(pd) std(pd) ACC(pd,1);100*(mean(exret)+.5*var(exret)) 100*std(exret) 0]'; 

% Basic Data Moments Quarterly Data
moment_mat_q=[400*mean(cons_q) 200*std(cons_q) ACC(cons_q,1); 400*mean(div_q) 200*std(div_q) ACC(div_q,1);400*mean(ret_q) 200*std(ret_q) ACC(ret_q,1); 400*mean(rf_q) 400*std(rf_q) ...
    ACC(rf_q,1); mean(pd_q) std(pd_q) ACC(pd_q,1);400*(mean(exret_q)+.5*var(exret_q)) 200*std(exret_q) 0]'; 

% 5 Autocorrelations of consumption and dividend growth in Yearly Data
ACc=zeros(5,1); ACd=zeros(5,1);
for i=1:5; 
ACc(i,1)=ACC(cons,i); ACd(i,1)=ACC(div,i); 
end; 
AC_y=[ACc ACd]; 

% 5 Autocorrelations of consumption and dividend growth in Postwar Data
ACc_q=zeros(5,1); ACd_q=zeros(5,1);
for i=1:5; 
ACc_q(i,1)=ACC(cons_q_ann,i); ACd_q(i,1)=ACC(div_q_ann,i); 
end; 
AC_q=[ACc_q ACd_q]; 

% Variance Ratios consumption and dividend growth in Yearly Data
AVc=var_ratio(cons,5); AVd=var_ratio(div,5);

% Variance Ratios consumption in quarterly Data
AVc_q=var_ratio(cons_q_ann,5); AVd_q=var_ratio(div_q_ann,5);

% Predictability Regressions Yearly Data 
[beta_cons t_cons r_cons]=year_hor_reg(cons,pd,1); 
[beta_div t_div r_div]=year_hor_reg(div,pd,1); 
[beta_ret t_ret r_ret]=year_hor_reg(exret,pd,1); 
predict_ret_y=[beta_ret t_ret r_ret];predict_cons_y=[beta_cons t_cons r_cons]; predict_div_y=[beta_div t_div r_div]; 

% Predictability Regressions Quarterly Data
[beta_cons_q t_cons_q r_cons_q]=year_hor_reg(cons_q,pd_q,4); 
[beta_div_q t_div_q r_div_q]=year_hor_reg(div_q,pd_q,4); 
[beta_ret_q t_ret_q r_ret_q]=year_hor_reg(exret_q,pd_q,4); 
predict_ret_q=[beta_ret_q t_ret_q r_ret_q];predict_cons_q=[beta_cons_q t_cons_q r_cons_q]; predict_div_q=[beta_div_q t_div_q r_div_q]; 

% Multivariate Predictability Regressions Yearly Data 
[beta_cons_mv t_cons_mv r_cons_mv]=year_hor_reg_mv(cons,cons,pd,rf,1); 
[beta_div_mv t_div_mv r_div_mv]=year_hor_reg_mv(div,div,pd,rf,1); 
[beta_ret_mv t_ret_mv r_ret_mv]=year_hor_reg_mv(exret,exret,pd,rf,1); 
predict_ret_y_mv=[beta_ret_mv t_ret_mv r_ret_mv];predict_cons_y_mv=[beta_cons_mv t_cons_mv r_cons_mv]; predict_div_y_mv=[beta_div_mv t_div_mv r_div_mv]; 

% Multivariate Predictability of Interest rates Yearly Data 
[beta_rf_mv t_rf_mv r_rf_mv]=year_hor_reg_mv(rf,cons,pd,rf,1); 

predict_rf_y_mv=[beta_rf_mv t_rf_mv r_rf_mv];




% Predictability of Volatility Yearly Data
[B1 yhat_consv R1]=OLS(cons(2:T,1),cons(1:T-1,1)); 
[B2 yhat_divv R2]=OLS(div(2:T,1),div(1:T-1,1)); 
[B3 yhat_exretv R3]=OLS(exret(2:T,1),exret(1:T-1,1)); 
abc=abs(cons(2:T,1)-yhat_consv); abd=abs(div(2:T,1)-yhat_divv); abr=abs(exret(2:T,1)-yhat_exretv); 
[beta_cv t_cv r_cv]=year_hor_reg_log(abc,pd(2:T,1),1); 
[beta_dv t_dv r_dv]=year_hor_reg_log(abd,pd(2:T,1),1); 
[beta_rv t_rv r_rv]=year_hor_reg_log(abr,pd(2:T,1),1); 
predict_retv_y=[beta_rv t_rv r_rv];predict_consv_y=[beta_cv t_cv r_cv];predict_divv_y=[beta_dv t_dv r_dv]; 

% Predictability of Volatility Quarterly Data
[B1_q yhat_consv_q R1_q]=OLS(cons_q(2:T_q,1),cons_q(1:T_q-1,1)); 
[B2_q yhat_divv_q R2_q]=OLS(div_q(2:T_q,1),div_q(1:T_q-1,1)); 
[B3_q yhat_exretv_q R3_q]=OLS(exret_q(2:T_q,1),exret_q(1:T_q-1,1)); 
abc_q=abs(cons_q(2:T_q,1)-yhat_consv_q); abd_q=abs(div_q(2:T_q,1)-yhat_divv_q); abr_q=abs(exret_q(2:T_q,1)-yhat_exretv_q); 
[beta_cv_q t_cv_q r_cv_q]=year_hor_reg_log(abc_q,pd_q(2:T_q,1),4); 
[beta_dv_q t_dv_q r_dv_q]=year_hor_reg_log(abd_q,pd_q(2:T_q,1),4); 
[beta_rv_q t_rv_q r_rv_q]=year_hor_reg_log(abr_q,pd_q(2:T_q,1),4); 
predict_retv_q=[beta_rv_q t_rv_q r_rv_q];predict_consv_q=[beta_cv_q t_cv_q r_cv_q];predict_divv_q=[beta_dv_q t_dv_q r_dv_q]; 

% EIS Regressions rf then re Yearly Data
x=ones(T-2,2); x(:,2)=cons(3:T,:); y=rf(3:T,:); z=[ones(T-2,1) cons(1:T-2,1) pd(1:T-2,1) rf(1:T-2,1)]; 
est_rf_inv=1/twoSLS(y,x,z); 
x(:,2)=rf(3:T,:); y=cons(3:T,:); 
est_rf=twoSLS(y,x,z); 

x=ones(T-2,2); x(:,2)=cons(3:T,:); y=ret(3:T,:); z=[ones(T-2,1) cons(1:T-2,1) pd(1:T-2,1) ret(1:T-2,1)]; 
est_ret_inv=1/twoSLS(y,x,z); 
x(:,2)=ret(3:T,:); y=cons(3:T,:); 
est_ret=twoSLS(y,x,z); 

% EIS Regressions rf then re Quarterly Data
x_q=ones(T_q-2,2); x_q(:,2)=cons_q(3:T_q,:); y_q=rf_q(3:T_q,:); z_q=[ones(T_q-2,1) cons_q(1:T_q-2,1) pd_q(1:T_q-2,1) rf_q(1:T_q-2,1)]; 
est_rf_inv_q=1/twoSLS(y_q,x_q,z_q); 
x_q(:,2)=rf_q(3:T_q,:); y_q=cons_q(3:T_q,:); 
est_rf_q=twoSLS(y_q,x_q,z_q); 

x_q=ones(T_q-2,2); x_q(:,2)=cons_q(3:T_q,:); y_q=ret_q(3:T_q,:); z_q=[ones(T_q-2,1) cons_q(1:T_q-2,1) pd_q(1:T_q-2,1) ret_q(1:T_q-2,1)]; 
est_ret_inv_q=1/twoSLS(y_q,x_q,z_q); 
x_q(:,2)=ret_q(3:T_q,:); y_q=cons_q(3:T_q,:); 
est_ret_q=twoSLS(y_q,x_q,z_q); 

% EIS Regressions rf then re Yearly Data full set of instruments

x=ones(T-2,2); x(:,2)=cons(3:T,:); y=rf(3:T,:); z=[ones(T-2,1) cons(1:T-2,1) pd(1:T-2,1) rf(1:T-2,1) ret(1:T-2,1)]; 
est_rf_inv_full=1/twoSLS(y,x,z); 
x(:,2)=rf(3:T,:); y=cons(3:T,:); 
est_rf_full=twoSLS(y,x,z); 

x=ones(T-2,2); x(:,2)=cons(3:T,:); y=ret(3:T,:); z=[ones(T-2,1) cons(1:T-2,1) pd(1:T-2,1) rf(1:T-2,1) ret(1:T-2,1)]; 
est_ret_inv_full=1/twoSLS(y,x,z); 
x(:,2)=ret(3:T,:); y=cons(3:T,:); 
est_ret_full=twoSLS(y,x,z); 

% EIS Regressions rf then re Quarterly Data full set of instruments

x_q=ones(T_q-2,2); x_q(:,2)=cons_q(3:T_q,:); y_q=rf_q(3:T_q,:); z_q=[ones(T_q-2,1) cons_q(1:T_q-2,1) pd_q(1:T_q-2,1) rf_q(1:T_q-2,1) ret_q(1:T_q-2,1)]; 
est_rf_inv_q_full=1/twoSLS(y_q,x_q,z_q); 
x_q(:,2)=rf_q(3:T_q,:); y_q=cons_q(3:T_q,:); 
est_rf_q_full=twoSLS(y_q,x_q,z_q); 

x_q=ones(T_q-2,2); x_q(:,2)=cons_q(3:T_q,:); y_q=ret_q(3:T_q,:); z_q=[ones(T_q-2,1) cons_q(1:T_q-2,1) pd_q(1:T_q-2,1) rf_q(1:T_q-2,1) ret_q(1:T_q-2,1)]; 
est_ret_inv_q_full=1/twoSLS(y_q,x_q,z_q); 
x_q(:,2)=ret_q(3:T_q,:); y_q=cons_q(3:T_q,:); 
est_ret_q_full=twoSLS(y_q,x_q,z_q); 


% Time Lag Regressions for Yearly Data

[beta_time1 beta_time3 beta_time5 r_time1 r_time3 r_time5]=lag_reg_y(cons,pd); 
[beta_time1_q beta_time3_q beta_time5_q r_time1_q r_time3_q r_time5_q]=lag_reg_q(cons_q,pd_q); 



% Finite Sample Simulations

% Generate Matrices to Store Output
Mom_y_BY=zeros(3,6,simnum); Mom_y_BKY=zeros(3,6,simnum); Mom_q_BY=zeros(3,6,simnum); Mom_q_BKY=zeros(3,6,simnum); 
low_EIS_BY=zeros(6,simnum); low_EIS_BKY=zeros(6,simnum); 
no_vol_BY=zeros(2,simnum); no_vol_BKY=zeros(2,simnum); 
iid_model_BY=zeros(2,simnum); iid_model_BKY=zeros(2,simnum); 
AC_BY=zeros(5,2,simnum); AC_BKY=zeros(5,2,simnum); 
AC_BY_q=zeros(5,2,simnum); AC_BKY_q=zeros(5,2,simnum); 
ret_y_BY=zeros(3,2,simnum); cons_y_BY=zeros(3,2,simnum); div_y_BY=zeros(3,2,simnum); 
ret_y_BKY=zeros(3,2,simnum); cons_y_BKY=zeros(3,2,simnum); div_y_BKY=zeros(3,2,simnum); 
ret_q_BY=zeros(3,2,simnum); cons_q_BY=zeros(3,2,simnum); div_q_BY=zeros(3,2,simnum); 
ret_q_BKY=zeros(3,2,simnum); cons_q_BKY=zeros(3,2,simnum); div_q_BKY=zeros(3,2,simnum); 

ret_y_BY_mv=zeros(3,4,simnum); cons_y_BY_mv=zeros(3,4,simnum); div_y_BY_mv=zeros(3,4,simnum); 
ret_y_BKY_mv=zeros(3,4,simnum); cons_y_BKY_mv=zeros(3,4,simnum); div_y_BKY_mv=zeros(3,4,simnum);

rf_y_BY_mv=zeros(3,4,simnum); 
rf_y_BKY_mv=zeros(3,4,simnum); 

vol_ret_y_BY=zeros(3,2,simnum); vol_cons_y_BY=zeros(3,2,simnum); vol_div_y_BY=zeros(3,2,simnum); 
vol_ret_y_BKY=zeros(3,2,simnum); vol_cons_y_BKY=zeros(3,2,simnum); vol_div_y_BKY=zeros(3,2,simnum); 
vol_ret_q_BY=zeros(3,2,simnum); vol_cons_q_BY=zeros(3,2,simnum); vol_div_q_BY=zeros(3,2,simnum); 
vol_ret_q_BKY=zeros(3,2,simnum); vol_cons_q_BKY=zeros(3,2,simnum); vol_div_q_BKY=zeros(3,2,simnum); 

EIS_y_BY=zeros(4,simnum); EIS_y_BKY=zeros(4,simnum); EIS_q_BY=zeros(4,simnum); EIS_q_BKY=zeros(4,simnum); 
EIS_y_BY_full=zeros(4,simnum); EIS_y_BKY_full=zeros(4,simnum); EIS_q_BY_full=zeros(4,simnum); EIS_q_BKY_full=zeros(4,simnum); 

con_vr_BY=zeros(5,simnum); con_vr_BKY=zeros(5,simnum); div_vr_BY=zeros(5,simnum); div_vr_BKY=zeros(5,simnum); 
con_vr_BY_q=zeros(5,simnum); con_vr_BKY_q=zeros(5,simnum);div_vr_BY_q=zeros(5,simnum); div_vr_BKY_q=zeros(5,simnum);


ts_finite_BY=zeros(4,9,simnum); ts_finite_BKY=zeros(4,9,simnum); 

beta_time1_BY=zeros(9,simnum); beta_time3_BY=zeros(9,simnum); beta_time5_BY=zeros(9,simnum); 
r_time1_BY=zeros(9,simnum); r_time3_BY=zeros(9,simnum); r_time5_BY=zeros(9,simnum); 
beta_time1_q_BY=zeros(33,simnum); beta_time3_q_BY=zeros(33,simnum); beta_time5_q_BY=zeros(33,simnum); 
r_time1_q_BY=zeros(33,simnum); r_time3_q_BY=zeros(33,simnum); r_time5_q_BY=zeros(33,simnum); 

beta_time1_BKY=zeros(9,simnum); beta_time3_BKY=zeros(9,simnum); beta_time5_BKY=zeros(9,simnum); 
r_time1_BKY=zeros(9,simnum); r_time3_BKY=zeros(9,simnum); r_time5_BKY=zeros(9,simnum); 
beta_time1_q_BKY=zeros(33,simnum); beta_time3_q_BKY=zeros(33,simnum); beta_time5_q_BKY=zeros(33,simnum); 
r_time1_q_BKY=zeros(33,simnum); r_time3_q_BKY=zeros(33,simnum); r_time5_q_BKY=zeros(33,simnum); 

GD_down_BY=zeros(simnum,1); GD_rec_BY=zeros(simnum,1); GD_down_num_BY=zeros(simnum,1); GD_rec_num_BY=zeros(simnum,1); 
GD_down_BKY=zeros(simnum,1); GD_rec_BKY=zeros(simnum,1); GD_down_num_BKY=zeros(simnum,1); GD_rec_num_BKY=zeros(simnum,1); 

% Begin Simulations

Indicator_yBY=zeros(simnum,1); 
Indicator_yBKY=zeros(simnum,1); 
Indicator_qBY=zeros(simnum,1); 
Indicator_qBKY=zeros(simnum,1); 

numcens_yBY=zeros(simnum,1); 
numcens_yBKY=zeros(simnum,1); 
numcens_qBY=zeros(simnum,1); 
numcens_qBKY=zeros(simnum,1); 

for i=1:simnum; 
i
% Generate Data

[BY_pyf Indicator_yBY(i,1) numcens_yBY(i,1) ] =BY_generate_y(yearly_months); 
[BY_pqf BY_pqf_an Indicator_qBY(i,1) numcens_qBY(i,1)]=BY_generate_q(quarterly_months); 
[BKY_pyf Indicator_yBKY(i,1) numcens_yBKY(i,1)]=BKY_generate_y(yearly_months); 
[BKY_pqf BKY_pqf_an Indicator_qBKY(i,1) numcens_qBKY(i,1)]=BKY_generate_q(quarterly_months); 

% Yearly Moments BY Model
Mom_y_BY(:,:,i)=[100*mean(BY_pyf(:,1)) 100*std(BY_pyf(:,1)) ACC(BY_pyf(:,1),1); 100*mean(BY_pyf(:,2)) 100*std(BY_pyf(:,2)) ACC(BY_pyf(:,2),1);100*mean(BY_pyf(:,4))...
    100*std(BY_pyf(:,4)) ACC(BY_pyf(:,4),1); 100*mean(BY_pyf(:,5)) 100*std(BY_pyf(:,5)) ACC(BY_pyf(:,5),1); mean(BY_pyf(:,3)) ...
    std(BY_pyf(:,3)) ACC(BY_pyf(:,3),1);100*(mean(BY_pyf(:,6))+.5*var(BY_pyf(:,6))) 100*std(BY_pyf(:,6)) 0]'; 

% Yearly Moments BKY Model
Mom_y_BKY(:,:,i)=[100*mean(BKY_pyf(:,1)) 100*std(BKY_pyf(:,1)) ACC(BKY_pyf(:,1),1); 100*mean(BKY_pyf(:,2)) 100*std(BKY_pyf(:,2)) ACC(BKY_pyf(:,2),1);100*mean(BKY_pyf(:,4))...
    100*std(BKY_pyf(:,4)) ACC(BKY_pyf(:,4),1); 100*mean(BKY_pyf(:,5)) 100*std(BKY_pyf(:,5)) ACC(BKY_pyf(:,5),1); mean(BKY_pyf(:,3)) ...
    std(BKY_pyf(:,3)) ACC(BKY_pyf(:,3),1);100*(mean(BKY_pyf(:,6))+.5*var(BKY_pyf(:,6))) 100*std(BKY_pyf(:,6)) 0]'; 
    
% Quarterly Moments BY Model
Mom_q_BY(:,:,i)=[400*mean(BY_pqf(:,1)) 200*std(BY_pqf(:,1)) ACC(BY_pqf(:,1),1); 400*mean(BY_pqf(:,2)) 200*std(BY_pqf(:,2)) ACC(BY_pqf(:,2),1);400*mean(BY_pqf(:,4)) ...
    200*std(BY_pqf(:,4)) ACC(BY_pqf(:,4),1); 400*mean(BY_pqf(:,5)) 400*std(BY_pqf(:,5)) ACC(BY_pqf(:,5),1); mean(BY_pqf(:,3)) ...
    std(BY_pqf(:,3)) ACC(BY_pqf(:,3),1);400*(mean(BY_pqf(:,6))+.5*var(BY_pqf(:,6))) 200*std(BY_pqf(:,6)) 0]'; 

% Quarterly Moments BKY Model
Mom_q_BKY(:,:,i)=[400*mean(BKY_pqf(:,1)) 200*std(BKY_pqf(:,1)) ACC(BKY_pqf(:,1),1); 400*mean(BKY_pqf(:,2)) 200*std(BKY_pqf(:,2)) ACC(BKY_pqf(:,2),1);400*mean(BKY_pqf(:,4)) ...
    200*std(BKY_pqf(:,4)) ACC(BKY_pqf(:,4),1); 400*mean(BKY_pqf(:,5)) 400*std(BKY_pqf(:,5)) ACC(BKY_pqf(:,5),1); mean(BKY_pqf(:,3)) ...
    std(BKY_pqf(:,3)) ACC(BKY_pqf(:,3),1);400*(mean(BKY_pqf(:,6))+.5*var(BKY_pqf(:,6))) 200*std(BKY_pqf(:,6)) 0]'; 

% Autocorrelations BY Yearly
ACc=zeros(5,1); ACd=zeros(5,1);
for j=1:5; 
ACc(j,1)=ACC(BY_pyf(:,1),j); ACd(j,1)=ACC(BY_pyf(:,2),j); 
end; 
AC_BY(:,:,i)=[ACc ACd]; 


% Autocorrelations BKY Yearly
ACc=zeros(5,1); ACd=zeros(5,1);
for j=1:5; 
ACc(j,1)=ACC(BKY_pyf(:,1),j); ACd(j,1)=ACC(BKY_pyf(:,2),j); 
end; 
AC_BKY(:,:,i)=[ACc ACd]; 


% Autocorrelations BY Quarterly
ACc=zeros(5,1); ACd=zeros(5,1);
for j=1:5; 
ACc(j,1)=ACC(BY_pqf_an(:,1),j); ACd(j,1)=ACC(BY_pqf_an(:,2),j); 
end; 
AC_BY_q(:,:,i)=[ACc ACd]; 


% Autocorrelations BKY Quarterly 
ACc=zeros(5,1); ACd=zeros(5,1);
for j=1:5; 
ACc(j,1)=ACC(BKY_pqf_an(:,1),j); ACd(j,1)=ACC(BKY_pqf_an(:,2),j); 
end; 
AC_BKY_q(:,:,i)=[ACc ACd]; 



% VR BY Yearly 
con_vr_BY(:,i)=var_ratio(BY_pyf(:,1),5); div_vr_BY(:,i)=var_ratio(BY_pyf(:,2),5); 

% VR BKY Yearly 
con_vr_BKY(:,i)=var_ratio(BKY_pyf(:,1),5); div_vr_BKY(:,i)=var_ratio(BKY_pyf(:,2),5); 


% VR BY quarterly
con_vr_BY_q(:,i)=var_ratio(BY_pqf_an(:,1),5); div_vr_BY_q(:,i)=var_ratio(BY_pqf_an(:,2),5);

% VR BKY quarterly 
con_vr_BKY_q(:,i)=var_ratio(BKY_pqf_an(:,1),5); div_vr_BKY_q(:,i)=var_ratio(BKY_pqf_an(:,2),5);
 


% Predictability Regressions Yearly BY Model
[beta_cons_BY t_cons_BY r_cons_BY]=year_hor_reg(BY_pyf(:,1),BY_pyf(:,3),1); 
[beta_div_BY t_div_BY r_div_BY]=year_hor_reg(BY_pyf(:,2),BY_pyf(:,3),1); 
[beta_ret_BY t_ret_BY r_ret_BY]=year_hor_reg(BY_pyf(:,6),BY_pyf(:,3),1); 
ret_y_BY(:,:,i)=[beta_ret_BY r_ret_BY];cons_y_BY(:,:,i)=[beta_cons_BY r_cons_BY]; div_y_BY(:,:,i)=[beta_div_BY r_div_BY]; 

% Predictability Regressions Yearly BKY Model
[beta_cons_BKY t_cons_BKY r_cons_BKY]=year_hor_reg(BKY_pyf(:,1),BKY_pyf(:,3),1); 
[beta_div_BKY t_div_BKY r_div_BKY]=year_hor_reg(BKY_pyf(:,2),BKY_pyf(:,3),1); 
[beta_ret_BKY t_ret_BKY r_ret_BKY]=year_hor_reg(BKY_pyf(:,6),BKY_pyf(:,3),1); 
ret_y_BKY(:,:,i)=[beta_ret_BKY r_ret_BKY];cons_y_BKY(:,:,i)=[beta_cons_BKY r_cons_BKY]; div_y_BKY(:,:,i)=[beta_div_BKY r_div_BKY]; 

% Predictability Regressions Quarterly BY Model
[beta_cons_q_BY t_cons_BY_q r_cons_q_BY]=year_hor_reg(BY_pqf(:,1),BY_pqf(:,3),4); 
[beta_div_q_BY t_div_q_BY r_div_q_BY]=year_hor_reg(BY_pqf(:,2),BY_pqf(:,3),4); 
[beta_ret_q_BY t_ret_q_BY r_ret_q_BY]=year_hor_reg(BY_pqf(:,6),BY_pqf(:,3),4); 
ret_q_BY(:,:,i)=[beta_ret_q_BY r_ret_q_BY];cons_q_BY(:,:,i)=[beta_cons_q_BY r_cons_q_BY]; div_q_BY(:,:,i)=[beta_div_q_BY r_div_q_BY]; 

% Predictability Regressions Quarterly BKY Model
[beta_cons_q_BKY t_cons_BKY_q r_cons_q_BKY]=year_hor_reg(BKY_pqf(:,1),BKY_pqf(:,3),4); 
[beta_div_q_BKY t_div_q_BKY r_div_q_BKY]=year_hor_reg(BKY_pqf(:,2),BKY_pqf(:,3),4); 
[beta_ret_q_BKY t_ret_q_BKY r_ret_q_BKY]=year_hor_reg(BKY_pqf(:,6),BKY_pqf(:,3),4); 
ret_q_BKY(:,:,i)=[beta_ret_q_BKY r_ret_q_BKY];cons_q_BKY(:,:,i)=[beta_cons_q_BKY r_cons_q_BKY]; div_q_BKY(:,:,i)=[beta_div_q_BKY r_div_q_BKY]; 


% Multivariate Predictability in Yearly BY Model
[beta_cons_BY_mv t_cons_BY_mv r_cons_BY_mv]=year_hor_reg_mv(BY_pyf(:,1),BY_pyf(:,1),BY_pyf(:,3),BY_pyf(:,5),1); 
[beta_div_BY_mv t_div_BY_mv r_div_BY_mv]=year_hor_reg_mv(BY_pyf(:,2),BY_pyf(:,2),BY_pyf(:,3),BY_pyf(:,5),1); 
[beta_ret_BY_mv t_ret_BY_mv r_ret_BY_mv]=year_hor_reg_mv(BY_pyf(:,6),BY_pyf(:,6),BY_pyf(:,3),BY_pyf(:,5),1); 
ret_y_BY_mv(:,:,i)=[beta_ret_BY_mv r_ret_BY_mv];cons_y_BY_mv(:,:,i)=[beta_cons_BY_mv r_cons_BY_mv];
div_y_BY_mv(:,:,i)=[beta_div_BY_mv r_div_BY_mv]; 

% Multivariate Predictability in Yearly BKY Model
[beta_cons_BKY_mv t_cons_BKY_mv r_cons_BKY_mv]=year_hor_reg_mv(BKY_pyf(:,1),BKY_pyf(:,1),BKY_pyf(:,3),BKY_pyf(:,5),1); 
[beta_div_BKY_mv t_div_BKY_mv r_div_BKY_mv]=year_hor_reg_mv(BKY_pyf(:,2),BKY_pyf(:,2),BKY_pyf(:,3),BKY_pyf(:,5),1); 
[beta_ret_BKY_mv t_ret_BKY_mv r_ret_BKY_mv]=year_hor_reg_mv(BKY_pyf(:,6),BKY_pyf(:,6),BKY_pyf(:,3),BKY_pyf(:,5),1); 
ret_y_BKY_mv(:,:,i)=[beta_ret_BKY_mv r_ret_BKY_mv];cons_y_BKY_mv(:,:,i)=[beta_cons_BKY_mv r_cons_BKY_mv];
div_y_BKY_mv(:,:,i)=[beta_div_BKY_mv r_div_BKY_mv]; 


% Multivariate Predictability of Interest rates Yearly BY Model
[beta_rf_BY_mv t_rf_BY_mv r_rf_BY_mv]=year_hor_reg_mv(BY_pyf(:,5),BY_pyf(:,1),BY_pyf(:,3),BY_pyf(:,5),1); 
rf_y_BY_mv(:,:,i)=[beta_rf_BY_mv r_rf_BY_mv];

% Multivariate Predictability of Interest rates Yearly BY Model
[beta_rf_BKY_mv t_rf_BKY_mv r_rf_BKY_mv]=year_hor_reg_mv(BKY_pyf(:,5),BKY_pyf(:,1),BKY_pyf(:,3),BKY_pyf(:,5),1); 
rf_y_BKY_mv(:,:,i)=[beta_rf_BKY_mv r_rf_BKY_mv];


% Predictability of Volatility Yearly BY Model
[B1_BYy yhat_consv_BYy R1_BYy]=OLS(BY_pyf(2:T,1),BY_pyf(1:T-1,1)); 
[B2_BYy yhat_divv_BYy R2_BYy]=OLS(BY_pyf(2:T,2),BY_pyf(1:T-1,2)); 
[B3_BYy yhat_exretv_BYy R3_BYy]=OLS(BY_pyf(2:T,6),BY_pyf(1:T-1,6)); 
abc_BYy=abs(BY_pyf(2:T,1)-yhat_consv_BYy); abd_BYy=abs(BY_pyf(2:T,2)-yhat_divv_BYy); abr_BYy=abs(BY_pyf(2:T,6)-yhat_exretv_BYy); 
[beta_cv_BYy t_cv_BYy r_cv_BYy]=year_hor_reg_log(abc_BYy,BY_pyf(2:T,3),1); 
[beta_dv_BYy t_dv_BYy r_dv_BYy]=year_hor_reg_log(abd_BYy,BY_pyf(2:T,3),1); 
[beta_rv_BYy t_rv_BYy r_rv_BYy]=year_hor_reg_log(abr_BYy,BY_pyf(2:T,3),1); 
vol_ret_y_BY(:,:,i)=[beta_rv_BYy r_rv_BYy];vol_cons_y_BY(:,:,i)=[beta_cv_BYy r_cv_BYy];vol_div_y_BY(:,:,i)=[beta_dv_BYy r_dv_BYy]; 




% Predictability of Volatility Yearly BKY Model
[B1_BKYy yhat_consv_BKYy R1_BKYy]=OLS(BKY_pyf(2:T,1),BKY_pyf(1:T-1,1)); 
[B2_BKYy yhat_divv_BKYy R2_BKYy]=OLS(BKY_pyf(2:T,2),BKY_pyf(1:T-1,2)); 
[B3_BKYy yhat_exretv_BKYy R3_BKYy]=OLS(BKY_pyf(2:T,6),BKY_pyf(1:T-1,6)); 
abc_BKYy=abs(BKY_pyf(2:T,1)-yhat_consv_BKYy); abd_BKYy=abs(BKY_pyf(2:T,2)-yhat_divv_BKYy); abr_BKYy=abs(BKY_pyf(2:T,6)-yhat_exretv_BKYy); 
[beta_cv_BKYy t_cv_BKYy r_cv_BKYy]=year_hor_reg_log(abc_BKYy,BKY_pyf(2:T,3),1); 
[beta_dv_BKYy t_dv_BKYy r_dv_BKYy]=year_hor_reg_log(abd_BKYy,BKY_pyf(2:T,3),1); 
[beta_rv_BKYy t_rv_BKYy r_rv_BKYy]=year_hor_reg_log(abr_BKYy,BKY_pyf(2:T,3),1); 
vol_ret_y_BKY(:,:,i)=[beta_rv_BKYy r_rv_BKYy];vol_cons_y_BKY(:,:,i)=[beta_cv_BKYy r_cv_BKYy];vol_div_y_BKY(:,:,i)=[beta_dv_BKYy r_dv_BKYy]; 

% Predictability of Volatility Quarterly BY MOdel
[B1_q_BY yhat_consv_q_BY R1_q_BY]=OLS(BY_pqf(2:T_q,1),BY_pqf(1:T_q-1,1)); 
[B2_q_BY yhat_divv_q_BY R2_q_BY]=OLS(BY_pqf(2:T_q,2),BY_pqf(1:T_q-1,2)); 
[B3_q_BY yhat_exretv_q_BY R3_q_BY]=OLS(BY_pqf(2:T_q,6),BY_pqf(1:T_q-1,6)); 
abc_q_BY=abs(BY_pqf(2:T_q,1)-yhat_consv_q_BY); abd_q_BY=abs(BY_pqf(2:T_q,2)-yhat_divv_q_BY); abr_q_BY=abs(BY_pqf(2:T_q,6)-yhat_exretv_q_BY); 
[beta_cv_q_BY t_cv_q_BY r_cv_q_BY]=year_hor_reg_log(abc_q_BY,BY_pqf(2:T_q,3),4); 
[beta_dv_q_BY t_dv_q_BY r_dv_q_BY]=year_hor_reg_log(abd_q_BY,BY_pqf(2:T_q,3),4); 
[beta_rv_q_BY t_rv_q_BY r_rv_q_BY]=year_hor_reg_log(abr_q_BY,BY_pqf(2:T_q,3),4); 
vol_ret_q_BY(:,:,i)=[beta_rv_q_BY r_rv_q_BY];vol_cons_q_BY(:,:,i)=[beta_cv_q_BY r_cv_q_BY];vol_div_q_BY(:,:,i)=[beta_dv_q_BY r_dv_q_BY]; 

% Predictability of Volatility Quarterly BKY MOdel
[B1_q_BKY yhat_consv_q_BKY R1_q_BYK]=OLS(BKY_pqf(2:T_q,1),BKY_pqf(1:T_q-1,1)); 
[B2_q_BKY yhat_divv_q_BKY R2_q_BKY]=OLS(BKY_pqf(2:T_q,2),BKY_pqf(1:T_q-1,2)); 
[B3_q_BKY yhat_exretv_q_BKY R3_q_BKY]=OLS(BKY_pqf(2:T_q,6),BKY_pqf(1:T_q-1,6)); 
abc_q_BKY=abs(BKY_pqf(2:T_q,1)-yhat_consv_q_BKY); abd_q_BKY=abs(BKY_pqf(2:T_q,2)-yhat_divv_q_BKY); abr_q_BKY=abs(BKY_pqf(2:T_q,6)-yhat_exretv_q_BKY); 
[beta_cv_q_BKY t_cv_q_BKY r_cv_q_BKY]=year_hor_reg_log(abc_q_BKY,BKY_pqf(2:T_q,3),4); 
[beta_dv_q_BKY t_dv_q_BKY r_dv_q_BKY]=year_hor_reg_log(abd_q_BKY,BKY_pqf(2:T_q,3),4); 
[beta_rv_q_BKY t_rv_q_BKY r_rv_q_BKY]=year_hor_reg_log(abr_q_BKY,BKY_pqf(2:T_q,3),4); 
vol_ret_q_BKY(:,:,i)=[beta_rv_q_BKY r_rv_q_BKY];vol_cons_q_BKY(:,:,i)=[beta_cv_q_BKY r_cv_q_BKY];vol_div_q_BKY(:,:,i)=[beta_dv_q_BKY r_dv_q_BKY]; 


% model with low EIS 

low_EIS_BY(:,i)=BY_low_eis(yearly_months); low_EIS_BKY(:,i)=BKY_low_eis(yearly_months); 


% model without time varying vol
no_vol_BY(:,i)=BY_no_vol(yearly_months); no_vol_BKY(:,i)=BKY_no_vol(yearly_months); 

% iid model
iid_model_BY(:,i)=BY_iid(yearly_months); iid_model_BKY(:,i)=BKY_iid(yearly_months); 


% EIS Regressions rf then re Yearly BY Model
x=ones(T-2,2); x(:,2)=BY_pyf(3:T,1); y=BY_pyf(3:T,5); z=[ones(T-2,1) BY_pyf(1:T-2,1) BY_pyf(1:T-2,3) BY_pyf(1:T-2,5)]; 
EIS_y_BY(3,i)=1/twoSLS(y,x,z); 
x(:,2)=BY_pyf(3:T,5); y=BY_pyf(3:T,1); 
EIS_y_BY(1,i)=twoSLS(y,x,z); 

x=ones(T-2,2); x(:,2)=BY_pyf(3:T,1); y=BY_pyf(3:T,4); z=[ones(T-2,1) BY_pyf(1:T-2,1) BY_pyf(1:T-2,3) BY_pyf(1:T-2,4)]; 
EIS_y_BY(4,i)=1/twoSLS(y,x,z); 
x(:,2)=BY_pyf(3:T,4); y=BY_pyf(3:T,1); 
EIS_y_BY(2,i)=twoSLS(y,x,z); 

% EIS Regressions rf then re Yearly BKY Model
x=ones(T-2,2); x(:,2)=BKY_pyf(3:T,1); y=BKY_pyf(3:T,5); z=[ones(T-2,1) BKY_pyf(1:T-2,1) BKY_pyf(1:T-2,3) BKY_pyf(1:T-2,5)]; 
EIS_y_BKY(3,i)=1/twoSLS(y,x,z); 
x(:,2)=BKY_pyf(3:T,5); y=BKY_pyf(3:T,1); 
EIS_y_BKY(1,i)=twoSLS(y,x,z); 

x=ones(T-2,2); x(:,2)=BKY_pyf(3:T,1); y=BKY_pyf(3:T,4); z=[ones(T-2,1) BKY_pyf(1:T-2,1) BKY_pyf(1:T-2,3) BKY_pyf(1:T-2,4)]; 
EIS_y_BKY(4,i)=1/twoSLS(y,x,z); 
x(:,2)=BKY_pyf(3:T,4); y=BKY_pyf(3:T,1); 
EIS_y_BKY(2,i)=twoSLS(y,x,z); 

% EIS Regressions rf then re Quarterly BY Model
x_q=ones(T_q-2,2); x_q(:,2)=BY_pqf(3:T_q,1); y_q=BY_pqf(3:T_q,5); z_q=[ones(T_q-2,1) BY_pqf(1:T_q-2,1) BY_pqf(1:T_q-2,3) BY_pqf(1:T_q-2,5)]; 
EIS_q_BY(3,i)=1/twoSLS(y_q,x_q,z_q); 
x_q(:,2)=BY_pqf(3:T_q,5); y_q=BY_pqf(3:T_q,1); 
EIS_q_BY(1,i)=twoSLS(y_q,x_q,z_q); 

x_q=ones(T_q-2,2); x_q(:,2)=BY_pqf(3:T_q,1); y_q=BY_pqf(3:T_q,4); z_q=[ones(T_q-2,1) BY_pqf(1:T_q-2,1) BY_pqf(1:T_q-2,3) BY_pqf(1:T_q-2,4)]; 
EIS_q_BY(4,i)=1/twoSLS(y_q,x_q,z_q); 
x_q(:,2)=BY_pqf(3:T_q,4); y_q=BY_pqf(3:T_q,1); 
EIS_q_BY(2,i)=twoSLS(y_q,x_q,z_q); 

% EIS Regressions rf then re Quarterly BKY Model
x_q=ones(T_q-2,2); x_q(:,2)=BKY_pqf(3:T_q,1); y_q=BKY_pqf(3:T_q,5); z_q=[ones(T_q-2,1) BKY_pqf(1:T_q-2,1) BKY_pqf(1:T_q-2,3) BKY_pqf(1:T_q-2,5)]; 
EIS_q_BKY(3,i)=1/twoSLS(y_q,x_q,z_q); 
x_q(:,2)=BKY_pqf(3:T_q,5); y_q=BKY_pqf(3:T_q,1); 
EIS_q_BKY(1,i)=twoSLS(y_q,x_q,z_q); 

x_q=ones(T_q-2,2); x_q(:,2)=BKY_pqf(3:T_q,1); y_q=BKY_pqf(3:T_q,4); z_q=[ones(T_q-2,1) BKY_pqf(1:T_q-2,1) BKY_pqf(1:T_q-2,3) BKY_pqf(1:T_q-2,4)]; 
EIS_q_BKY(4,i)=1/twoSLS(y_q,x_q,z_q); 
x_q(:,2)=BKY_pqf(3:T_q,4); y_q=BKY_pqf(3:T_q,1); 
EIS_q_BKY(2,i)=twoSLS(y_q,x_q,z_q); 



% EIS regressions with full set of instruments



% EIS Regressions rf then re Yearly BY Model
x=ones(T-2,2); x(:,2)=BY_pyf(3:T,1); y=BY_pyf(3:T,5); z=[ones(T-2,1) BY_pyf(1:T-2,1) BY_pyf(1:T-2,3) BY_pyf(1:T-2,4) BY_pyf(1:T-2,5)]; 
EIS_y_BY_full(3,i)=1/twoSLS(y,x,z); 
x(:,2)=BY_pyf(3:T,5); y=BY_pyf(3:T,1); 
EIS_y_BY_full(1,i)=twoSLS(y,x,z); 

x=ones(T-2,2); x(:,2)=BY_pyf(3:T,1); y=BY_pyf(3:T,4); z=[ones(T-2,1) BY_pyf(1:T-2,1) BY_pyf(1:T-2,3) BY_pyf(1:T-2,4) BY_pyf(1:T-2,5)]; 
EIS_y_BY_full(4,i)=1/twoSLS(y,x,z); 
x(:,2)=BY_pyf(3:T,4); y=BY_pyf(3:T,1); 
EIS_y_BY_full(2,i)=twoSLS(y,x,z); 

% EIS Regressions rf then re Yearly BKY Model
x=ones(T-2,2); x(:,2)=BKY_pyf(3:T,1); y=BKY_pyf(3:T,5); z=[ones(T-2,1) BKY_pyf(1:T-2,1) BKY_pyf(1:T-2,3) BKY_pyf(1:T-2,4) BKY_pyf(1:T-2,5)]; 
EIS_y_BKY_full(3,i)=1/twoSLS(y,x,z); 
x(:,2)=BKY_pyf(3:T,5); y=BKY_pyf(3:T,1); 
EIS_y_BKY_full(1,i)=twoSLS(y,x,z); 

x=ones(T-2,2); x(:,2)=BKY_pyf(3:T,1); y=BKY_pyf(3:T,4); z=[ones(T-2,1) BKY_pyf(1:T-2,1) BKY_pyf(1:T-2,3) BKY_pyf(1:T-2,4) BKY_pyf(1:T-2,5)]; 
EIS_y_BKY_full(4,i)=1/twoSLS(y,x,z); 
x(:,2)=BKY_pyf(3:T,4); y=BKY_pyf(3:T,1); 
EIS_y_BKY_full(2,i)=twoSLS(y,x,z); 

% EIS Regressions rf then re Quarterly BY Model
x_q=ones(T_q-2,2); x_q(:,2)=BY_pqf(3:T_q,1); y_q=BY_pqf(3:T_q,5); z_q=[ones(T_q-2,1) BY_pqf(1:T_q-2,1) BY_pqf(1:T_q-2,3) BY_pqf(1:T_q-2,4) BY_pqf(1:T_q-2,5)]; 
EIS_q_BY_full(3,i)=1/twoSLS(y_q,x_q,z_q); 
x_q(:,2)=BY_pqf(3:T_q,5); y_q=BY_pqf(3:T_q,1); 
EIS_q_BY_full(1,i)=twoSLS(y_q,x_q,z_q); 

x_q=ones(T_q-2,2); x_q(:,2)=BY_pqf(3:T_q,1); y_q=BY_pqf(3:T_q,4); z_q=[ones(T_q-2,1) BY_pqf(1:T_q-2,1) BY_pqf(1:T_q-2,3) BY_pqf(1:T_q-2,4) BY_pqf(1:T_q-2,5)]; 
EIS_q_BY_full(4,i)=1/twoSLS(y_q,x_q,z_q); 
x_q(:,2)=BY_pqf(3:T_q,4); y_q=BY_pqf(3:T_q,1); 
EIS_q_BY_full(2,i)=twoSLS(y_q,x_q,z_q); 

% EIS Regressions rf then re Quarterly BKY Model
x_q=ones(T_q-2,2); x_q(:,2)=BKY_pqf(3:T_q,1); y_q=BKY_pqf(3:T_q,5); z_q=[ones(T_q-2,1) BKY_pqf(1:T_q-2,1) BKY_pqf(1:T_q-2,3) BKY_pqf(1:T_q-2,4) BKY_pqf(1:T_q-2,5)]; 
EIS_q_BKY_full(3,i)=1/twoSLS(y_q,x_q,z_q); 
x_q(:,2)=BKY_pqf(3:T_q,5); y_q=BKY_pqf(3:T_q,1); 
EIS_q_BKY_full(1,i)=twoSLS(y_q,x_q,z_q); 

x_q=ones(T_q-2,2); x_q(:,2)=BKY_pqf(3:T_q,1); y_q=BKY_pqf(3:T_q,4); z_q=[ones(T_q-2,1) BKY_pqf(1:T_q-2,1) BKY_pqf(1:T_q-2,3) BKY_pqf(1:T_q-2,4) BKY_pqf(1:T_q-2,5)]; 
EIS_q_BKY_full(4,i)=1/twoSLS(y_q,x_q,z_q); 
x_q(:,2)=BKY_pqf(3:T_q,4); y_q=BKY_pqf(3:T_q,1); 
EIS_q_BKY_full(2,i)=twoSLS(y_q,x_q,z_q); 


% Term STructure Moments

ts_finite_BY(:,:,i)=BY_TS(yearly_months); ts_finite_BKY(:,:,i)=BKY_TS(yearly_months); 


% Lead and Lag Regressions

[beta_time1_BY(:,i) beta_time3_BY(:,i) beta_time5_BY(:,i) r_time1_BY(:,i) r_time3_BY(:,i) r_time5_BY(:,i)]=lag_reg_y(BY_pyf(:,1),BY_pyf(:,3)); 
[beta_time1_q_BY(:,i) beta_time3_q_BY(:,i) beta_time5_q_BY(:,i) r_time1_q_BY(:,i) r_time3_q_BY(:,i) r_time5_q_BY(:,i)]=lag_reg_q(BY_pqf(:,1),BY_pqf(:,3)); 

[beta_time1_BKY(:,i) beta_time3_BKY(:,i) beta_time5_BKY(:,i) r_time1_BKY(:,i) r_time3_BKY(:,i) r_time5_BKY(:,i)]=lag_reg_y(BKY_pyf(:,1),BKY_pyf(:,3)); 
[beta_time1_q_BKY(:,i) beta_time3_q_BKY(:,i) beta_time5_q_BKY(:,i) r_time1_q_BKY(:,i) r_time3_q_BKY(:,i) r_time5_q_BKY(:,i)]=lag_reg_q(BKY_pqf(:,1),BKY_pqf(:,3)); 

% Great Depression Yearly 
[GD_down_BY(i,1) GD_rec_BY(i,1) GD_down_num_BY(i,1) GD_rec_num_BY(i,1)]=Great_Depression(BY_pyf(:,1)); 
[GD_down_BKY(i,1) GD_rec_BKY(i,1) GD_down_num_BKY(i,1) GD_rec_num_BKY(i,1)]=Great_Depression(BKY_pyf(:,1)); 


end; 



Med_mom_y_BY=zeros(3,6); 
Med_mom_y_BKY=zeros(3,6); 
Med_mom_q_BY=zeros(3,6); 
Med_mom_q_BKY=zeros(3,6); 


for i=1:3; 
for j=1:6; 
    
Med_mom_y_BY(i,j)=quantile(Mom_y_BY(i,j,:),.5);   
Med_mom_y_BKY(i,j)=quantile(Mom_y_BKY(i,j,:),.5);   
Med_mom_q_BY(i,j)=quantile(Mom_q_BY(i,j,:),.5);   
Med_mom_q_BKY(i,j)=quantile(Mom_q_BKY(i,j,:),.5);  
    
    
end; 
end; 


AC_cons_50_BY=zeros(5,1); AC_div_50_BY=zeros(5,1); AC_cons_50_BKY=zeros(5,1); AC_div_50_BKY=zeros(5,1); 

AC_cons_perc_BY=zeros(5,1); AC_div_perc_BY=zeros(5,1); AC_cons_perc_BKY=zeros(5,1); AC_div_perc_BKY=zeros(5,1); 

AC_cons_50_BY_q=zeros(5,1); AC_div_50_BY_q=zeros(5,1); AC_cons_50_BKY_q=zeros(5,1); AC_div_50_BKY_q=zeros(5,1); 

AC_cons_perc_BY_q=zeros(5,1); AC_div_perc_BY_q=zeros(5,1); AC_cons_perc_BKY_q=zeros(5,1); AC_div_perc_BKY_q=zeros(5,1); 

for i=1:5; 
AC_cons_50_BY(i,1)=quantile(AC_BY(i,1,:),.5); 
AC_cons_50_BKY(i,1)=quantile(AC_BKY(i,1,:),.5); 
AC_div_50_BY(i,1)=quantile(AC_BY(i,2,:),.5); 
AC_div_50_BKY(i,1)=quantile(AC_BKY(i,2,:),.5); 

AC_cons_50_BY_q(i,1)=quantile(AC_BY_q(i,1,:),.5); 
AC_cons_50_BKY_q(i,1)=quantile(AC_BKY_q(i,1,:),.5); 
AC_div_50_BY_q(i,1)=quantile(AC_BY_q(i,2,:),.5); 
AC_div_50_BKY_q(i,1)=quantile(AC_BKY_q(i,2,:),.5); 


AC_cons_perc_BY(i,1)=(find([-1000; sort(reshape(AC_BY(i,1,:),simnum,1,1))]<AC_y(i,1), 1, 'last' )-1)/simnum; 
AC_cons_perc_BKY(i,1)=(find([-1000; sort(reshape(AC_BKY(i,1,:),simnum,1,1))]<AC_y(i,1), 1, 'last' )-1)/simnum; 
AC_div_perc_BY(i,1)=(find([-1000; sort(reshape(AC_BY(i,2,:),simnum,1,1))]<AC_y(i,2), 1, 'last' )-1)/simnum; 
AC_div_perc_BKY(i,1)=(find([-1000; sort(reshape(AC_BKY(i,2,:),simnum,1,1))]<AC_y(i,2), 1, 'last' )-1)/simnum; 

AC_cons_perc_BY_q(i,1)=(find([-1000; sort(reshape(AC_BY_q(i,1,:),simnum,1,1))]<AC_q(i,1), 1, 'last' )-1)/simnum; 
AC_cons_perc_BKY_q(i,1)=(find([-1000; sort(reshape(AC_BKY_q(i,1,:),simnum,1,1))]<AC_q(i,1), 1, 'last' )-1)/simnum; 
AC_div_perc_BY_q(i,1)=(find([-1000; sort(reshape(AC_BY_q(i,2,:),simnum,1,1))]<AC_q(i,2), 1, 'last' )-1)/simnum; 
AC_div_perc_BKY_q(i,1)=(find([-1000; sort(reshape(AC_BKY_q(i,2,:),simnum,1,1))]<AC_q(i,2), 1, 'last' )-1)/simnum; 

end;

cons_VR_50_BY=zeros(5,1); div_VR_50_BY=zeros(5,1); cons_VR_50_BKY=zeros(5,1); div_VR_50_BKY=zeros(5,1); 
cons_VR_perc_BY=zeros(5,1); div_VR_perc_BY=zeros(5,1); cons_VR_perc_BKY=zeros(5,1); div_VR_perc_BKY=zeros(5,1); 

cons_VR_50_BY_q=zeros(5,1); cons_VR_50_BKY_q=zeros(5,1); div_VR_50_BY_q=zeros(5,1); div_VR_50_BKY_q=zeros(5,1); 
cons_VR_perc_BY_q=zeros(5,1);  cons_VR_perc_BKY_q=zeros(5,1); div_VR_perc_BY_q=zeros(5,1);  div_VR_perc_BKY_q=zeros(5,1); 

for i=1:5; 
cons_VR_50_BY(i,1)=quantile(con_vr_BY(i,:),.5); 
cons_VR_50_BKY(i,1)=quantile(con_vr_BKY(i,:),.5); 
div_VR_50_BY(i,1)=quantile(div_vr_BY(i,:),.5); 
div_VR_50_BKY(i,1)=quantile(div_vr_BKY(i,:),.5); 

cons_VR_perc_BY(i,1)=(find([-1000; sort(reshape(con_vr_BY(i,:),simnum,1))]<AVc(i,1), 1, 'last' )-1)/simnum; 
cons_VR_perc_BKY(i,1)=(find([-1000; sort(reshape(con_vr_BKY(i,:),simnum,1))]<AVc(i,1), 1, 'last' )-1)/simnum; 
div_VR_perc_BY(i,1)=(find([-1000; sort(reshape(div_vr_BY(i,:),simnum,1))]<AVd(i,1), 1, 'last' )-1)/simnum; 
div_VR_perc_BKY(i,1)=(find([-1000; sort(reshape(div_vr_BKY(i,:),simnum,1))]<AVd(i,1), 1, 'last' )-1)/simnum; 
    
    
end; 


for i=1:5; 
    
cons_VR_50_BY_q(i,1)=quantile(con_vr_BY_q(i,:),.5); 
cons_VR_50_BKY_q(i,1)=quantile(con_vr_BKY_q(i,:),.5); 
div_VR_50_BY_q(i,1)=quantile(div_vr_BY_q(i,:),.5); 
div_VR_50_BKY_q(i,1)=quantile(div_vr_BKY_q(i,:),.5); 

cons_VR_perc_BY_q(i,1)=(find([-1000; sort(reshape(con_vr_BY_q(i,:),simnum,1))]<AVc_q(i,1), 1, 'last' )-1)/simnum; 
cons_VR_perc_BKY_q(i,1)=(find([-1000; sort(reshape(con_vr_BKY_q(i,:),simnum,1))]<AVc_q(i,1), 1, 'last' )-1)/simnum; 
div_VR_perc_BY_q(i,1)=(find([-1000; sort(reshape(div_vr_BY_q(i,:),simnum,1))]<AVd_q(i,1), 1, 'last' )-1)/simnum; 
div_VR_perc_BKY_q(i,1)=(find([-1000; sort(reshape(div_vr_BKY_q(i,:),simnum,1))]<AVd_q(i,1), 1, 'last' )-1)/simnum; 
    
end; 

Ret_50_BY_y_b=zeros(3,1); Cons_50_BY_y_b=zeros(3,1); Div_50_BY_y_b=zeros(3,1); 
Ret_50_BKY_y_b=zeros(3,1); Cons_50_BKY_y_b=zeros(3,1); Div_50_BKY_y_b=zeros(3,1); 
Ret_50_BY_q_b=zeros(3,1); Cons_50_BY_q_b=zeros(3,1); Div_50_BY_q_b=zeros(3,1); 
Ret_50_BKY_q_b=zeros(3,1); Cons_50_BKY_q_b=zeros(3,1); Div_50_BKY_q_b=zeros(3,1); 

Ret_perc_BY_y_b=zeros(3,1); Cons_perc_BY_y_b=zeros(3,1); Div_perc_BY_y_b=zeros(3,1); 
Ret_perc_BKY_y_b=zeros(3,1); Cons_perc_BKY_y_b=zeros(3,1); Div_perc_BKY_y_b=zeros(3,1); 
Ret_perc_BY_q_b=zeros(3,1); Cons_perc_BY_q_b=zeros(3,1); Div_perc_BY_q_b=zeros(3,1); 
Ret_perc_BKY_q_b=zeros(3,1); Cons_perc_BKY_q_b=zeros(3,1); Div_perc_BKY_q_b=zeros(3,1); 

Ret_50_BY_y_r=zeros(3,1); Cons_50_BY_y_r=zeros(3,1); Div_50_BY_y_r=zeros(3,1); 
Ret_50_BKY_y_r=zeros(3,1); Cons_50_BKY_y_r=zeros(3,1); Div_50_BKY_y_r=zeros(3,1); 
Ret_50_BY_q_r=zeros(3,1); Cons_50_BY_q_r=zeros(3,1); Div_50_BY_q_r=zeros(3,1); 
Ret_50_BKY_q_r=zeros(3,1); Cons_50_BKY_q_r=zeros(3,1); Div_50_BKY_q_r=zeros(3,1); 

Ret_perc_BY_y_r=zeros(3,1); Cons_perc_BY_y_r=zeros(3,1); Div_perc_BY_y_r=zeros(3,1); 
Ret_perc_BKY_y_r=zeros(3,1); Cons_perc_BKY_y_r=zeros(3,1); Div_perc_BKY_y_r=zeros(3,1); 
Ret_perc_BY_q_r=zeros(3,1); Cons_perc_BY_q_r=zeros(3,1); Div_perc_BY_q_r=zeros(3,1); 
Ret_perc_BKY_q_r=zeros(3,1); Cons_perc_BKY_q_r=zeros(3,1); Div_perc_BKY_q_r=zeros(3,1); 

for i=1:3; 
Ret_50_BY_y_b(i,1)=quantile(ret_y_BY(i,1,:),.5); 
Cons_50_BY_y_b(i,1)=quantile(cons_y_BY(i,1,:),.5); 
Div_50_BY_y_b(i,1)=quantile(div_y_BY(i,1,:),.5); 

Ret_50_BY_y_r(i,1)=quantile(ret_y_BY(i,2,:),.5); 
Cons_50_BY_y_r(i,1)=quantile(cons_y_BY(i,2,:),.5); 
Div_50_BY_y_r(i,1)=quantile(div_y_BY(i,2,:),.5); 

Ret_50_BKY_y_b(i,1)=quantile(ret_y_BKY(i,1,:),.5); 
Cons_50_BKY_y_b(i,1)=quantile(cons_y_BKY(i,1,:),.5); 
Div_50_BKY_y_b(i,1)=quantile(div_y_BKY(i,1,:),.5); 

Ret_50_BKY_y_r(i,1)=quantile(ret_y_BKY(i,2,:),.5); 
Cons_50_BKY_y_r(i,1)=quantile(cons_y_BKY(i,2,:),.5); 
Div_50_BKY_y_r(i,1)=quantile(div_y_BKY(i,2,:),.5); 


Ret_50_BY_q_b(i,1)=quantile(ret_q_BY(i,1,:),.5); 
Cons_50_BY_q_b(i,1)=quantile(cons_q_BY(i,1,:),.5); 
Div_50_BY_q_b(i,1)=quantile(div_q_BY(i,1,:),.5); 

Ret_50_BY_q_r(i,1)=quantile(ret_q_BY(i,2,:),.5); 
Cons_50_BY_q_r(i,1)=quantile(cons_q_BY(i,2,:),.5); 
Div_50_BY_q_r(i,1)=quantile(div_q_BY(i,2,:),.5); 

Ret_50_BKY_q_b(i,1)=quantile(ret_q_BKY(i,1,:),.5); 
Cons_50_BKY_q_b(i,1)=quantile(cons_q_BKY(i,1,:),.5); 
Div_50_BKY_q_b(i,1)=quantile(div_q_BKY(i,1,:),.5); 

Ret_50_BKY_q_r(i,1)=quantile(ret_q_BKY(i,2,:),.5); 
Cons_50_BKY_q_r(i,1)=quantile(cons_q_BKY(i,2,:),.5); 
Div_50_BKY_q_r(i,1)=quantile(div_q_BKY(i,2,:),.5); 

Ret_perc_BY_y_b(i,1)=(find([-1000; sort(reshape(ret_y_BY(i,1,:),simnum,1,1))]<predict_ret_y(i,1), 1, 'last' )-1)/simnum; 
Cons_perc_BY_y_b(i,1)=(find([-1000; sort(reshape(cons_y_BY(i,1,:),simnum,1,1))]<predict_cons_y(i,1), 1, 'last' )-1)/simnum; 
Div_perc_BY_y_b(i,1)=(find([-1000; sort(reshape(div_y_BY(i,1,:),simnum,1,1))]<predict_div_y(i,1), 1, 'last' )-1)/simnum; 

Ret_perc_BY_y_r(i,1)=(find([-1000; sort(reshape(ret_y_BY(i,2,:),simnum,1,1))]<predict_ret_y(i,3), 1, 'last' )-1)/simnum; 
Cons_perc_BY_y_r(i,1)=(find([-1000; sort(reshape(cons_y_BY(i,2,:),simnum,1,1))]<predict_cons_y(i,3), 1, 'last' )-1)/simnum; 
Div_perc_BY_y_r(i,1)=(find([-1000; sort(reshape(div_y_BY(i,2,:),simnum,1,1))]<predict_div_y(i,3), 1, 'last' )-1)/simnum; 

Ret_perc_BKY_y_b(i,1)=(find([-1000; sort(reshape(ret_y_BKY(i,1,:),simnum,1,1))]<predict_ret_y(i,1), 1, 'last' )-1)/simnum; 
Cons_perc_BKY_y_b(i,1)=(find([-1000; sort(reshape(cons_y_BKY(i,1,:),simnum,1,1))]<predict_cons_y(i,1), 1, 'last' )-1)/simnum; 
Div_perc_BKY_y_b(i,1)=(find([-1000; sort(reshape(div_y_BKY(i,1,:),simnum,1,1))]<predict_div_y(i,1), 1, 'last' )-1)/simnum; 

Ret_perc_BKY_y_r(i,1)=(find([-1000; sort(reshape(ret_y_BKY(i,2,:),simnum,1,1))]<predict_ret_y(i,3), 1, 'last' )-1)/simnum; 
Cons_perc_BKY_y_r(i,1)=(find([-1000; sort(reshape(cons_y_BKY(i,2,:),simnum,1,1))]<predict_cons_y(i,3), 1, 'last' )-1)/simnum; 
Div_perc_BKY_y_r(i,1)=(find([-1000; sort(reshape(div_y_BKY(i,2,:),simnum,1,1))]<predict_div_y(i,3), 1, 'last' )-1)/simnum; 

Ret_perc_BY_q_b(i,1)=(find([-1000; sort(reshape(ret_q_BY(i,1,:),simnum,1,1))]<predict_ret_q(i,1), 1, 'last' )-1)/simnum; 
Cons_perc_BY_q_b(i,1)=(find([-1000; sort(reshape(cons_q_BY(i,1,:),simnum,1,1))]<predict_cons_q(i,1), 1, 'last' )-1)/simnum; 
Div_perc_BY_q_b(i,1)=(find([-1000; sort(reshape(div_q_BY(i,1,:),simnum,1,1))]<predict_div_q(i,1), 1, 'last' )-1)/simnum; 

Ret_perc_BY_q_r(i,1)=(find([-1000; sort(reshape(ret_q_BY(i,2,:),simnum,1,1))]<predict_ret_q(i,3), 1, 'last' )-1)/simnum; 
Cons_perc_BY_q_r(i,1)=(find([-1000; sort(reshape(cons_q_BY(i,2,:),simnum,1,1))]<predict_cons_q(i,3), 1, 'last' )-1)/simnum; 
Div_perc_BY_q_r(i,1)=(find([-1000; sort(reshape(div_q_BY(i,2,:),simnum,1,1))]<predict_div_q(i,3), 1, 'last' )-1)/simnum; 

Ret_perc_BKY_q_b(i,1)=(find([-1000; sort(reshape(ret_q_BKY(i,1,:),simnum,1,1))]<predict_ret_q(i,1), 1, 'last' )-1)/simnum; 
Cons_perc_BKY_q_b(i,1)=(find([-1000; sort(reshape(cons_q_BKY(i,1,:),simnum,1,1))]<predict_cons_q(i,1), 1, 'last' )-1)/simnum; 
Div_perc_BKY_q_b(i,1)=(find([-1000; sort(reshape(div_q_BKY(i,1,:),simnum,1,1))]<predict_div_q(i,1), 1, 'last' )-1)/simnum; 

Ret_perc_BKY_q_r(i,1)=(find([-1000; sort(reshape(ret_q_BKY(i,2,:),simnum,1,1))]<predict_ret_q(i,3), 1, 'last' )-1)/simnum; 
Cons_perc_BKY_q_r(i,1)=(find([-1000; sort(reshape(cons_q_BKY(i,2,:),simnum,1,1))]<predict_cons_q(i,3), 1, 'last' )-1)/simnum; 
Div_perc_BKY_q_r(i,1)=(find([-1000; sort(reshape(div_q_BKY(i,2,:),simnum,1,1))]<predict_div_q(i,3), 1, 'last' )-1)/simnum; 




end; 



Ret_50_BY_y_r_mv=zeros(3,1); Cons_50_BY_y_r_mv=zeros(3,1); Div_50_BY_y_r_mv=zeros(3,1); 
Ret_50_BKY_y_r_mv=zeros(3,1); Cons_50_BKY_y_r_mv=zeros(3,1); Div_50_BKY_y_r_mv=zeros(3,1); 

Ret_perc_BY_y_r_mv=zeros(3,1); Cons_perc_BY_y_r_mv=zeros(3,1); Div_perc_BY_y_r_mv=zeros(3,1); 
Ret_perc_BKY_y_r_mv=zeros(3,1); Cons_perc_BKY_y_r_mv=zeros(3,1); Div_perc_BKY_y_r_mv=zeros(3,1); 

Rf_50_BY_y_r_mv=zeros(3,1); 
Rf_50_BKY_y_r_mv=zeros(3,1); 

Rf_perc_BY_y_r_mv=zeros(3,1); 
Rf_perc_BKY_y_r_mv=zeros(3,1); 


for i=1:3; 

Ret_50_BY_y_r_mv(i,1)=quantile(ret_y_BY_mv(i,4,:),.5); 
Cons_50_BY_y_r_mv(i,1)=quantile(cons_y_BY_mv(i,4,:),.5); 
Div_50_BY_y_r_mv(i,1)=quantile(div_y_BY_mv(i,4,:),.5); 
Rf_50_BY_y_r_mv(i,1)=quantile(rf_y_BY_mv(i,4,:),.5); 

Ret_50_BKY_y_r_mv(i,1)=quantile(ret_y_BKY_mv(i,4,:),.5); 
Cons_50_BKY_y_r_mv(i,1)=quantile(cons_y_BKY_mv(i,4,:),.5); 
Div_50_BKY_y_r_mv(i,1)=quantile(div_y_BKY_mv(i,4,:),.5); 
Rf_50_BKY_y_r_mv(i,1)=quantile(rf_y_BKY_mv(i,4,:),.5); 


Ret_perc_BY_y_r_mv(i,1)=(find([-1000; sort(reshape(ret_y_BY_mv(i,4,:),simnum,1,1))]<predict_ret_y_mv(i,7), 1, 'last' )-1)/simnum; 
Cons_perc_BY_y_r_mv(i,1)=(find([-1000; sort(reshape(cons_y_BY_mv(i,4,:),simnum,1,1))]<predict_cons_y_mv(i,7), 1, 'last' )-1)/simnum; 
Div_perc_BY_y_r_mv(i,1)=(find([-1000; sort(reshape(div_y_BY_mv(i,4,:),simnum,1,1))]<predict_div_y_mv(i,7), 1, 'last' )-1)/simnum; 
Rf_perc_BY_y_r_mv(i,1)=(find([-1000; sort(reshape(rf_y_BY_mv(i,4,:),simnum,1,1))]<predict_rf_y_mv(i,7), 1, 'last' )-1)/simnum; 

Ret_perc_BKY_y_r_mv(i,1)=(find([-1000; sort(reshape(ret_y_BKY_mv(i,4,:),simnum,1,1))]<predict_ret_y_mv(i,7), 1, 'last' )-1)/simnum; 
Cons_perc_BKY_y_r_mv(i,1)=(find([-1000; sort(reshape(cons_y_BKY_mv(i,4,:),simnum,1,1))]<predict_cons_y_mv(i,7), 1, 'last' )-1)/simnum; 
Div_perc_BKY_y_r_mv(i,1)=(find([-1000; sort(reshape(div_y_BKY_mv(i,4,:),simnum,1,1))]<predict_div_y_mv(i,7), 1, 'last' )-1)/simnum; 
Rf_perc_BKY_y_r_mv(i,1)=(find([-1000; sort(reshape(rf_y_BKY_mv(i,4,:),simnum,1,1))]<predict_rf_y_mv(i,7), 1, 'last' )-1)/simnum; 

end; 



vRet_50_BY_y_b=zeros(3,1); vCons_50_BY_y_b=zeros(3,1); vDiv_50_BY_y_b=zeros(3,1); 
vRet_50_BKY_y_b=zeros(3,1); vCons_50_BKY_y_b=zeros(3,1); vDiv_50_BKY_y_b=zeros(3,1); 
vRet_50_BY_q_b=zeros(3,1); vCons_50_BY_q_b=zeros(3,1); vDiv_50_BY_q_b=zeros(3,1); 
vRet_50_BKY_q_b=zeros(3,1); vCons_50_BKY_q_b=zeros(3,1); vDiv_50_BKY_q_b=zeros(3,1); 

vRet_perc_BY_y_b=zeros(3,1); vCons_perc_BY_y_b=zeros(3,1); vDiv_perc_BY_y_b=zeros(3,1); 
vRet_perc_BKY_y_b=zeros(3,1); vCons_perc_BKY_y_b=zeros(3,1); vDiv_perc_BKY_y_b=zeros(3,1); 
vRet_perc_BY_q_b=zeros(3,1); vCons_perc_BY_q_b=zeros(3,1); vDiv_perc_BY_q_b=zeros(3,1); 
vRet_perc_BKY_q_b=zeros(3,1); vCons_perc_BKY_q_b=zeros(3,1); vDiv_perc_BKY_q_b=zeros(3,1); 

vRet_50_BY_y_r=zeros(3,1); vCons_50_BY_y_r=zeros(3,1); vDiv_50_BY_y_r=zeros(3,1); 
vRet_50_BKY_y_r=zeros(3,1); vCons_50_BKY_y_r=zeros(3,1); vDiv_50_BKY_y_r=zeros(3,1); 
vRet_50_BY_q_r=zeros(3,1); vCons_50_BY_q_r=zeros(3,1); vDiv_50_BY_q_r=zeros(3,1); 
vRet_50_BKY_q_r=zeros(3,1); vCons_50_BKY_q_r=zeros(3,1); vDiv_50_BKY_q_r=zeros(3,1); 

vRet_perc_BY_y_r=zeros(3,1); vCons_perc_BY_y_r=zeros(3,1); vDiv_perc_BY_y_r=zeros(3,1); 
vRet_perc_BKY_y_r=zeros(3,1); vCons_perc_BKY_y_r=zeros(3,1); vDiv_perc_BKY_y_r=zeros(3,1); 
vRet_perc_BY_q_r=zeros(3,1); vCons_perc_BY_q_r=zeros(3,1); vDiv_perc_BY_q_r=zeros(3,1); 
vRet_perc_BKY_q_r=zeros(3,1); vCons_perc_BKY_q_r=zeros(3,1); vDiv_perc_BKY_q_r=zeros(3,1); 


for i=1:3; 
    
vRet_50_BY_y_b(i,1)=quantile(vol_ret_y_BY(i,1,:),.5); 
vCons_50_BY_y_b(i,1)=quantile(vol_cons_y_BY(i,1,:),.5); 
vDiv_50_BY_y_b(i,1)=quantile(vol_div_y_BY(i,1,:),.5); 

vRet_50_BY_y_r(i,1)=quantile(vol_ret_y_BY(i,2,:),.5); 
vCons_50_BY_y_r(i,1)=quantile(vol_cons_y_BY(i,2,:),.5); 
vDiv_50_BY_y_r(i,1)=quantile(vol_div_y_BY(i,2,:),.5); 

vRet_50_BKY_y_b(i,1)=quantile(vol_ret_y_BKY(i,1,:),.5); 
vCons_50_BKY_y_b(i,1)=quantile(vol_cons_y_BKY(i,1,:),.5); 
vDiv_50_BKY_y_b(i,1)=quantile(vol_div_y_BKY(i,1,:),.5); 

vRet_50_BKY_y_r(i,1)=quantile(vol_ret_y_BKY(i,2,:),.5); 
vCons_50_BKY_y_r(i,1)=quantile(vol_cons_y_BKY(i,2,:),.5); 
vDiv_50_BKY_y_r(i,1)=quantile(vol_div_y_BKY(i,2,:),.5); 


vRet_50_BY_q_b(i,1)=quantile(vol_ret_q_BY(i,1,:),.5); 
vCons_50_BY_q_b(i,1)=quantile(vol_cons_q_BY(i,1,:),.5); 
vDiv_50_BY_q_b(i,1)=quantile(vol_div_q_BY(i,1,:),.5); 

vRet_50_BY_q_r(i,1)=quantile(vol_ret_q_BY(i,2,:),.5); 
vCons_50_BY_q_r(i,1)=quantile(vol_cons_q_BY(i,2,:),.5); 
vDiv_50_BY_q_r(i,1)=quantile(vol_div_q_BY(i,2,:),.5); 

vRet_50_BKY_q_b(i,1)=quantile(vol_ret_q_BKY(i,1,:),.5); 
vCons_50_BKY_q_b(i,1)=quantile(vol_cons_q_BKY(i,1,:),.5); 
vDiv_50_BKY_q_b(i,1)=quantile(vol_div_q_BKY(i,1,:),.5); 

vRet_50_BKY_q_r(i,1)=quantile(vol_ret_q_BKY(i,2,:),.5); 
vCons_50_BKY_q_r(i,1)=quantile(vol_cons_q_BKY(i,2,:),.5); 
vDiv_50_BKY_q_r(i,1)=quantile(vol_div_q_BKY(i,2,:),.5); 

vRet_perc_BY_y_b(i,1)=(find([-1000; sort(reshape(vol_ret_y_BY(i,1,:),simnum,1,1))]<predict_retv_y(i,1), 1, 'last' )-1)/simnum; 
vCons_perc_BY_y_b(i,1)=(find([-1000; sort(reshape(vol_cons_y_BY(i,1,:),simnum,1,1))]<predict_consv_y(i,1), 1, 'last' )-1)/simnum; 
vDiv_perc_BY_y_b(i,1)=(find([-1000; sort(reshape(vol_div_y_BY(i,1,:),simnum,1,1))]<predict_divv_y(i,1), 1, 'last' )-1)/simnum; 

vRet_perc_BY_y_r(i,1)=(find([-1000; sort(reshape(vol_ret_y_BY(i,2,:),simnum,1,1))]<predict_retv_y(i,3), 1, 'last' )-1)/simnum; 
vCons_perc_BY_y_r(i,1)=(find([-1000; sort(reshape(vol_cons_y_BY(i,2,:),simnum,1,1))]<predict_consv_y(i,3), 1, 'last' )-1)/simnum; 
vDiv_perc_BY_y_r(i,1)=(find([-1000; sort(reshape(vol_div_y_BY(i,2,:),simnum,1,1))]<predict_divv_y(i,3), 1, 'last' )-1)/simnum; 

vRet_perc_BKY_y_b(i,1)=(find([-1000; sort(reshape(vol_ret_y_BKY(i,1,:),simnum,1,1))]<predict_retv_y(i,1), 1, 'last' )-1)/simnum; 
vCons_perc_BKY_y_b(i,1)=(find([-1000; sort(reshape(vol_cons_y_BKY(i,1,:),simnum,1,1))]<predict_consv_y(i,1), 1, 'last' )-1)/simnum; 
vDiv_perc_BKY_y_b(i,1)=(find([-1000; sort(reshape(vol_div_y_BKY(i,1,:),simnum,1,1))]<predict_divv_y(i,1), 1, 'last' )-1)/simnum; 

vRet_perc_BKY_y_r(i,1)=(find([-1000; sort(reshape(vol_ret_y_BKY(i,2,:),simnum,1,1))]<predict_retv_y(i,3), 1, 'last' )-1)/simnum; 
vCons_perc_BKY_y_r(i,1)=(find([-1000; sort(reshape(vol_cons_y_BKY(i,2,:),simnum,1,1))]<predict_consv_y(i,3), 1, 'last' )-1)/simnum; 
vDiv_perc_BKY_y_r(i,1)=(find([-1000; sort(reshape(vol_div_y_BKY(i,2,:),simnum,1,1))]<predict_divv_y(i,3), 1, 'last' )-1)/simnum; 

vRet_perc_BY_q_b(i,1)=(find([-1000; sort(reshape(vol_ret_q_BY(i,1,:),simnum,1,1))]<predict_retv_q(i,1), 1, 'last' )-1)/simnum; 
vCons_perc_BY_q_b(i,1)=(find([-1000; sort(reshape(vol_cons_q_BY(i,1,:),simnum,1,1))]<predict_consv_q(i,1), 1, 'last' )-1)/simnum; 
vDiv_perc_BY_q_b(i,1)=(find([-1000; sort(reshape(vol_div_q_BY(i,1,:),simnum,1,1))]<predict_divv_q(i,1), 1, 'last' )-1)/simnum; 

vRet_perc_BY_q_r(i,1)=(find([-1000; sort(reshape(vol_ret_q_BY(i,2,:),simnum,1,1))]<predict_retv_q(i,3), 1, 'last' )-1)/simnum; 
vCons_perc_BY_q_r(i,1)=(find([-1000; sort(reshape(vol_cons_q_BY(i,2,:),simnum,1,1))]<predict_consv_q(i,3), 1, 'last' )-1)/simnum; 
vDiv_perc_BY_q_r(i,1)=(find([-1000; sort(reshape(vol_div_q_BY(i,2,:),simnum,1,1))]<predict_divv_q(i,3), 1, 'last' )-1)/simnum; 

vRet_perc_BKY_q_b(i,1)=(find([-1000; sort(reshape(vol_ret_q_BKY(i,1,:),simnum,1,1))]<predict_retv_q(i,1), 1, 'last' )-1)/simnum; 
vCons_perc_BKY_q_b(i,1)=(find([-1000; sort(reshape(vol_cons_q_BKY(i,1,:),simnum,1,1))]<predict_consv_q(i,1), 1, 'last' )-1)/simnum; 
vDiv_perc_BKY_q_b(i,1)=(find([-1000; sort(reshape(vol_div_q_BKY(i,1,:),simnum,1,1))]<predict_divv_q(i,1), 1, 'last' )-1)/simnum; 

vRet_perc_BKY_q_r(i,1)=(find([-1000; sort(reshape(vol_ret_q_BKY(i,2,:),simnum,1,1))]<predict_retv_q(i,3), 1, 'last' )-1)/simnum; 
vCons_perc_BKY_q_r(i,1)=(find([-1000; sort(reshape(vol_cons_q_BKY(i,2,:),simnum,1,1))]<predict_consv_q(i,3), 1, 'last' )-1)/simnum; 
vDiv_perc_BKY_q_r(i,1)=(find([-1000; sort(reshape(vol_div_q_BKY(i,2,:),simnum,1,1))]<predict_divv_q(i,3), 1, 'last' )-1)/simnum; 


end; 



ret_ret_mv_50_BY=zeros(3,1); 
ret_pd_mv_50_BY=zeros(3,1); 
ret_rf_mv_50_BY=zeros(3,1); 

cons_cons_mv_50_BY=zeros(3,1); 
cons_pd_mv_50_BY=zeros(3,1); 
cons_rf_mv_50_BY=zeros(3,1); 

div_div_mv_50_BY=zeros(3,1); 
div_pd_mv_50_BY=zeros(3,1); 
div_rf_mv_50_BY=zeros(3,1); 

rf_cons_mv_50_BY=zeros(3,1); 
rf_pd_mv_50_BY=zeros(3,1); 
rf_rf_mv_50_BY=zeros(3,1); 

ret_ret_mv_perc_BY=zeros(3,1); 
ret_pd_mv_perc_BY=zeros(3,1); 
ret_rf_mv_perc_BY=zeros(3,1); 

cons_cons_mv_perc_BY=zeros(3,1); 
cons_pd_mv_perc_BY=zeros(3,1); 
cons_rf_mv_perc_BY=zeros(3,1); 

div_div_mv_perc_BY=zeros(3,1); 
div_pd_mv_perc_BY=zeros(3,1); 
div_rf_mv_perc_BY=zeros(3,1); 

rf_cons_mv_perc_BY=zeros(3,1); 
rf_pd_mv_perc_BY=zeros(3,1); 
rf_rf_mv_perc_BY=zeros(3,1); 

ret_ret_mv_50_BKY=zeros(3,1); 
ret_pd_mv_50_BKY=zeros(3,1); 
ret_rf_mv_50_BKY=zeros(3,1); 

cons_cons_mv_50_BKY=zeros(3,1); 
cons_pd_mv_50_BKY=zeros(3,1); 
cons_rf_mv_50_BKY=zeros(3,1); 

div_div_mv_50_BKY=zeros(3,1); 
div_pd_mv_50_BKY=zeros(3,1); 
div_rf_mv_50_BKY=zeros(3,1); 

rf_cons_mv_50_BKY=zeros(3,1); 
rf_pd_mv_50_BKY=zeros(3,1); 
rf_rf_mv_50_BKY=zeros(3,1); 

ret_ret_mv_perc_BKY=zeros(3,1); 
ret_pd_mv_perc_BKY=zeros(3,1); 
ret_rf_mv_perc_BKY=zeros(3,1); 

cons_cons_mv_perc_BKY=zeros(3,1); 
cons_pd_mv_perc_BKY=zeros(3,1); 
cons_rf_mv_perc_BKY=zeros(3,1); 

div_div_mv_perc_BKY=zeros(3,1); 
div_pd_mv_perc_BKY=zeros(3,1); 
div_rf_mv_perc_BKY=zeros(3,1); 

rf_cons_mv_perc_BKY=zeros(3,1); 
rf_pd_mv_perc_BKY=zeros(3,1); 
rf_rf_mv_perc_BKY=zeros(3,1); 


for i=1:3; 

ret_ret_mv_50_BY(i,1)=quantile(ret_y_BY_mv(i,1,:),.5); 
ret_pd_mv_50_BY(i,1)=quantile(ret_y_BY_mv(i,2,:),.5); 
ret_rf_mv_50_BY(i,1)=quantile(ret_y_BY_mv(i,3,:),.5);

cons_cons_mv_50_BY(i,1)=quantile(cons_y_BY_mv(i,1,:),.5); 
cons_pd_mv_50_BY(i,1)=quantile(cons_y_BY_mv(i,2,:),.5); 
cons_rf_mv_50_BY(i,1)=quantile(cons_y_BY_mv(i,3,:),.5); 

div_div_mv_50_BY(i,1)=quantile(div_y_BY_mv(i,1,:),.5); 
div_pd_mv_50_BY(i,1)=quantile(div_y_BY_mv(i,2,:),.5); 
div_rf_mv_50_BY(i,1)=quantile(div_y_BY_mv(i,3,:),.5); 

rf_cons_mv_50_BY(i,1)=quantile(rf_y_BY_mv(i,1,:),.5); 
rf_pd_mv_50_BY(i,1)=quantile(rf_y_BY_mv(i,2,:),.5); 
rf_rf_mv_50_BY(i,1)=quantile(rf_y_BY_mv(i,3,:),.5); 

ret_ret_mv_50_BKY(i,1)=quantile(ret_y_BKY_mv(i,1,:),.5); 
ret_pd_mv_50_BKY(i,1)=quantile(ret_y_BKY_mv(i,2,:),.5); 
ret_rf_mv_50_BKY(i,1)=quantile(ret_y_BKY_mv(i,3,:),.5);

cons_cons_mv_50_BKY(i,1)=quantile(cons_y_BKY_mv(i,1,:),.5); 
cons_pd_mv_50_BKY(i,1)=quantile(cons_y_BKY_mv(i,2,:),.5); 
cons_rf_mv_50_BKY(i,1)=quantile(cons_y_BKY_mv(i,3,:),.5); 

div_div_mv_50_BKY(i,1)=quantile(div_y_BKY_mv(i,1,:),.5); 
div_pd_mv_50_BKY(i,1)=quantile(div_y_BKY_mv(i,2,:),.5); 
div_rf_mv_50_BKY(i,1)=quantile(div_y_BKY_mv(i,3,:),.5); 

rf_cons_mv_50_BKY(i,1)=quantile(rf_y_BKY_mv(i,1,:),.5); 
rf_pd_mv_50_BKY(i,1)=quantile(rf_y_BKY_mv(i,2,:),.5); 
rf_rf_mv_50_BKY(i,1)=quantile(rf_y_BKY_mv(i,3,:),.5); 

ret_ret_mv_perc_BY(i,1)=(find([-1000; sort(reshape(ret_y_BY_mv(i,1,:),simnum,1,1))]<predict_ret_y_mv(i,1), 1, 'last' )-1)/simnum; 
ret_pd_mv_perc_BY(i,1)=(find([-1000; sort(reshape(ret_y_BY_mv(i,2,:),simnum,1,1))]<predict_ret_y_mv(i,2), 1, 'last' )-1)/simnum; 
ret_rf_mv_perc_BY(i,1)=(find([-1000; sort(reshape(ret_y_BY_mv(i,3,:),simnum,1,1))]<predict_ret_y_mv(i,3), 1, 'last' )-1)/simnum; 

cons_cons_mv_perc_BY(i,1)=(find([-1000; sort(reshape(cons_y_BY_mv(i,1,:),simnum,1,1))]<predict_cons_y_mv(i,1), 1, 'last' )-1)/simnum; 
cons_pd_mv_perc_BY(i,1)=(find([-1000; sort(reshape(cons_y_BY_mv(i,2,:),simnum,1,1))]<predict_cons_y_mv(i,2), 1, 'last' )-1)/simnum; 
cons_rf_mv_perc_BY(i,1)=(find([-1000; sort(reshape(cons_y_BY_mv(i,3,:),simnum,1,1))]<predict_cons_y_mv(i,3), 1, 'last' )-1)/simnum; 

div_div_mv_perc_BY(i,1)=(find([-1000; sort(reshape(div_y_BY_mv(i,1,:),simnum,1,1))]<predict_div_y_mv(i,1), 1, 'last' )-1)/simnum; 
div_pd_mv_perc_BY(i,1)=(find([-1000; sort(reshape(div_y_BY_mv(i,2,:),simnum,1,1))]<predict_div_y_mv(i,2), 1, 'last' )-1)/simnum; 
div_rf_mv_perc_BY(i,1)=(find([-1000; sort(reshape(div_y_BY_mv(i,3,:),simnum,1,1))]<predict_div_y_mv(i,3), 1, 'last' )-1)/simnum; 

rf_cons_mv_perc_BY(i,1)=(find([-1000; sort(reshape(rf_y_BY_mv(i,1,:),simnum,1,1))]<predict_rf_y_mv(i,1), 1, 'last' )-1)/simnum; 
rf_pd_mv_perc_BY(i,1)=(find([-1000; sort(reshape(rf_y_BY_mv(i,2,:),simnum,1,1))]<predict_rf_y_mv(i,2), 1, 'last' )-1)/simnum; 
rf_rf_mv_perc_BY(i,1)=(find([-1000; sort(reshape(rf_y_BY_mv(i,3,:),simnum,1,1))]<predict_rf_y_mv(i,3), 1, 'last' )-1)/simnum; 


ret_ret_mv_perc_BKY(i,1)=(find([-1000; sort(reshape(ret_y_BKY_mv(i,1,:),simnum,1,1))]<predict_ret_y_mv(i,1), 1, 'last' )-1)/simnum; 
ret_pd_mv_perc_BKY(i,1)=(find([-1000; sort(reshape(ret_y_BKY_mv(i,2,:),simnum,1,1))]<predict_ret_y_mv(i,2), 1, 'last' )-1)/simnum; 
ret_rf_mv_perc_BKY(i,1)=(find([-1000; sort(reshape(ret_y_BKY_mv(i,3,:),simnum,1,1))]<predict_ret_y_mv(i,3), 1, 'last' )-1)/simnum; 

cons_cons_mv_perc_BKY(i,1)=(find([-1000; sort(reshape(cons_y_BKY_mv(i,1,:),simnum,1,1))]<predict_cons_y_mv(i,1), 1, 'last' )-1)/simnum; 
cons_pd_mv_perc_BKY(i,1)=(find([-1000; sort(reshape(cons_y_BKY_mv(i,2,:),simnum,1,1))]<predict_cons_y_mv(i,2), 1, 'last' )-1)/simnum; 
cons_rf_mv_perc_BKY(i,1)=(find([-1000; sort(reshape(cons_y_BKY_mv(i,3,:),simnum,1,1))]<predict_cons_y_mv(i,3), 1, 'last' )-1)/simnum; 

div_div_mv_perc_BKY(i,1)=(find([-1000; sort(reshape(div_y_BKY_mv(i,1,:),simnum,1,1))]<predict_div_y_mv(i,1), 1, 'last' )-1)/simnum; 
div_pd_mv_perc_BKY(i,1)=(find([-1000; sort(reshape(div_y_BKY_mv(i,2,:),simnum,1,1))]<predict_div_y_mv(i,2), 1, 'last' )-1)/simnum; 
div_rf_mv_perc_BKY(i,1)=(find([-1000; sort(reshape(div_y_BKY_mv(i,3,:),simnum,1,1))]<predict_div_y_mv(i,3), 1, 'last' )-1)/simnum; 

rf_cons_mv_perc_BKY(i,1)=(find([-1000; sort(reshape(rf_y_BKY_mv(i,1,:),simnum,1,1))]<predict_rf_y_mv(i,1), 1, 'last' )-1)/simnum; 
rf_pd_mv_perc_BKY(i,1)=(find([-1000; sort(reshape(rf_y_BKY_mv(i,2,:),simnum,1,1))]<predict_rf_y_mv(i,2), 1, 'last' )-1)/simnum; 
rf_rf_mv_perc_BKY(i,1)=(find([-1000; sort(reshape(rf_y_BKY_mv(i,3,:),simnum,1,1))]<predict_rf_y_mv(i,3), 1, 'last' )-1)/simnum; 



    
end; 




low_EIS_med_BY=zeros(6,1); low_EIS_med_BKY=zeros(6,1); 


for i=1:6; 
 
low_EIS_med_BY(i,1)=quantile(low_EIS_BY(i,:),.5); 
low_EIS_med_BKY(i,1)=quantile(low_EIS_BKY(i,:),.5); 
    
end; 


rf_inv_50_BY_y=quantile(EIS_y_BY(3,:),.5);  rf_50_BY_y=quantile(EIS_y_BY(1,:),.5); re_inv_50_BY_y=quantile(EIS_y_BY(4,:),.5); re_50_BY_y=quantile(EIS_y_BY(2,:),.5);
rf_inv_50_BKY_y=quantile(EIS_y_BKY(3,:),.5);  rf_50_BKY_y=quantile(EIS_y_BKY(1,:),.5); re_inv_50_BKY_y=quantile(EIS_y_BKY(4,:),.5); re_50_BKY_y=quantile(EIS_y_BKY(2,:),.5);

rf_inv_50_BY_q=quantile(EIS_q_BY(3,:),.5);  rf_50_BY_q=quantile(EIS_q_BY(1,:),.5); re_inv_50_BY_q=quantile(EIS_q_BY(4,:),.5); re_50_BY_q=quantile(EIS_q_BY(2,:),.5);
rf_inv_50_BKY_q=quantile(EIS_q_BKY(3,:),.5);  rf_50_BKY_q=quantile(EIS_q_BKY(1,:),.5); re_inv_50_BKY_q=quantile(EIS_q_BKY(4,:),.5); re_50_BKY_q=quantile(EIS_q_BKY(2,:),.5);

rf_inv_50_BY_y_full=quantile(EIS_y_BY_full(3,:),.5);  rf_50_BY_y_full=quantile(EIS_y_BY_full(1,:),.5); 
re_inv_50_BY_y_full=quantile(EIS_y_BY_full(4,:),.5); re_50_BY_y_full=quantile(EIS_y_BY_full(2,:),.5);
rf_inv_50_BKY_y_full=quantile(EIS_y_BKY_full(3,:),.5);  rf_50_BKY_y_full=quantile(EIS_y_BKY_full(1,:),.5); 
re_inv_50_BKY_y_full=quantile(EIS_y_BKY_full(4,:),.5); re_50_BKY_y_full=quantile(EIS_y_BKY_full(2,:),.5);

rf_inv_50_BY_q_full=quantile(EIS_q_BY_full(3,:),.5);  rf_50_BY_q_full=quantile(EIS_q_BY_full(1,:),.5); 
re_inv_50_BY_q_full=quantile(EIS_q_BY_full(4,:),.5); re_50_BY_q_full=quantile(EIS_q_BY_full(2,:),.5);
rf_inv_50_BKY_q_full=quantile(EIS_q_BKY_full(3,:),.5);  rf_50_BKY_q_full=quantile(EIS_q_BKY_full(1,:),.5); 
re_inv_50_BKY_q_full=quantile(EIS_q_BKY_full(4,:),.5); re_50_BKY_q_full=quantile(EIS_q_BKY_full(2,:),.5);


rf_inv_perc_BY_y=(find([-1000; sort(reshape(EIS_y_BY(3,:),simnum,1,1))]<est_rf_inv, 1, 'last' )-1)/simnum;  
rf_perc_BY_y=(find([-1000; sort(reshape(EIS_y_BY(1,:),simnum,1,1))]<est_rf, 1, 'last' )-1)/simnum;  
re_inv_perc_BY_y=(find([-1000; sort(reshape(EIS_y_BY(4,:),simnum,1,1))]<est_ret_inv, 1, 'last' )-1)/simnum;  
re_perc_BY_y=(find([-1000; sort(reshape(EIS_y_BY(2,:),simnum,1,1))]<est_ret, 1, 'last' )-1)/simnum;  

rf_inv_perc_BKY_y=(find([-1000; sort(reshape(EIS_y_BKY(3,:),simnum,1,1))]<est_rf_inv, 1, 'last' )-1)/simnum;  
rf_perc_BKY_y=(find([-1000; sort(reshape(EIS_y_BKY(1,:),simnum,1,1))]<est_rf, 1, 'last' )-1)/simnum;  
re_inv_perc_BKY_y=(find([-1000; sort(reshape(EIS_y_BKY(4,:),simnum,1,1))]<est_ret_inv, 1, 'last' )-1)/simnum;  
re_perc_BKY_y=(find([-1000; sort(reshape(EIS_y_BKY(2,:),simnum,1,1))]<est_ret, 1, 'last' )-1)/simnum;  

rf_inv_perc_BY_q=(find([-1000; sort(reshape(EIS_q_BY(3,:),simnum,1,1))]<est_rf_inv_q, 1, 'last' )-1)/simnum;  
rf_perc_BY_q=(find([-1000; sort(reshape(EIS_q_BY(1,:),simnum,1,1))]<est_rf_q, 1, 'last' )-1)/simnum;  
re_inv_perc_BY_q=(find([-1000; sort(reshape(EIS_q_BY(4,:),simnum,1,1))]<est_ret_inv_q, 1, 'last' )-1)/simnum;  
re_perc_BY_q=(find([-1000; sort(reshape(EIS_q_BY(2,:),simnum,1,1))]<est_ret_q, 1, 'last' )-1)/simnum;  

rf_inv_perc_BKY_q=(find([-1000; sort(reshape(EIS_q_BKY(3,:),simnum,1,1))]<est_rf_inv_q, 1, 'last' )-1)/simnum;  
rf_perc_BKY_q=(find([-1000; sort(reshape(EIS_q_BKY(1,:),simnum,1,1))]<est_rf_q, 1, 'last' )-1)/simnum;  
re_inv_perc_BKY_q=(find([-1000; sort(reshape(EIS_q_BKY(4,:),simnum,1,1))]<est_ret_inv_q, 1, 'last' )-1)/simnum;  
re_perc_BKY_q=(find([-1000; sort(reshape(EIS_q_BKY(2,:),simnum,1,1))]<est_ret_q, 1, 'last' )-1)/simnum;  




rf_inv_perc_BY_y_full=(find([-1000; sort(reshape(EIS_y_BY_full(3,:),simnum,1,1))]<est_rf_inv_full, 1, 'last' )-1)/simnum;  
rf_perc_BY_y_full=(find([-1000; sort(reshape(EIS_y_BY_full(1,:),simnum,1,1))]<est_rf_full, 1, 'last' )-1)/simnum;  
re_inv_perc_BY_y_full=(find([-1000; sort(reshape(EIS_y_BY_full(4,:),simnum,1,1))]<est_ret_inv_full, 1, 'last' )-1)/simnum;  
re_perc_BY_y_full=(find([-1000; sort(reshape(EIS_y_BY_full(2,:),simnum,1,1))]<est_ret_full, 1, 'last' )-1)/simnum;  

rf_inv_perc_BKY_y_full=(find([-1000; sort(reshape(EIS_y_BKY_full(3,:),simnum,1,1))]<est_rf_inv_full, 1, 'last' )-1)/simnum;  
rf_perc_BKY_y_full=(find([-1000; sort(reshape(EIS_y_BKY_full(1,:),simnum,1,1))]<est_rf_full, 1, 'last' )-1)/simnum;  
re_inv_perc_BKY_y_full=(find([-1000; sort(reshape(EIS_y_BKY_full(4,:),simnum,1,1))]<est_ret_inv_full, 1, 'last' )-1)/simnum;  
re_perc_BKY_y_full=(find([-1000; sort(reshape(EIS_y_BKY_full(2,:),simnum,1,1))]<est_ret_full, 1, 'last' )-1)/simnum;  

rf_inv_perc_BY_q_full=(find([-1000; sort(reshape(EIS_q_BY_full(3,:),simnum,1,1))]<est_rf_inv_q_full, 1, 'last' )-1)/simnum;  
rf_perc_BY_q_full=(find([-1000; sort(reshape(EIS_q_BY_full(1,:),simnum,1,1))]<est_rf_q_full, 1, 'last' )-1)/simnum;  
re_inv_perc_BY_q_full=(find([-1000; sort(reshape(EIS_q_BY_full(4,:),simnum,1,1))]<est_ret_inv_q_full, 1, 'last' )-1)/simnum;  
re_perc_BY_q_full=(find([-1000; sort(reshape(EIS_q_BY_full(2,:),simnum,1,1))]<est_ret_q_full, 1, 'last' )-1)/simnum;  

rf_inv_perc_BKY_q_full=(find([-1000; sort(reshape(EIS_q_BKY_full(3,:),simnum,1,1))]<est_rf_inv_q_full, 1, 'last' )-1)/simnum;  
rf_perc_BKY_q_full=(find([-1000; sort(reshape(EIS_q_BKY_full(1,:),simnum,1,1))]<est_rf_q_full, 1, 'last' )-1)/simnum;  
re_inv_perc_BKY_q_full=(find([-1000; sort(reshape(EIS_q_BKY_full(4,:),simnum,1,1))]<est_ret_inv_q_full, 1, 'last' )-1)/simnum;  
re_perc_BKY_q_full=(find([-1000; sort(reshape(EIS_q_BKY_full(2,:),simnum,1,1))]<est_ret_q_full, 1, 'last' )-1)/simnum;  


TS_moments_BY=zeros(4,9); TS_moments_BKY=zeros(4,9); 

for i=1:4; 
for j=1:9; 
    
    
TS_moments_BY(i,j)=quantile(ts_finite_BY(i,j,:),.5); 
TS_moments_BKY(i,j)=quantile(ts_finite_BKY(i,j,:),.5); 

    
end; 
end; 


beta_time1_50_BY=zeros(9,1); beta_time3_50_BY=zeros(9,1); beta_time5_50_BY=zeros(9,1); 
r_time1_50_BY=zeros(9,1); r_time3_50_BY=zeros(9,1); r_time5_50_BY=zeros(9,1); 
beta_time1_50_BY_q=zeros(33,1); beta_time3_50_BY_q=zeros(33,1); beta_time5_50_BY_q=zeros(33,1); 
r_time1_50_BY_q=zeros(33,1); r_time3_50_BY_q=zeros(33,1); r_time5_50_BY_q=zeros(33,1); 

beta_time1_50_BKY=zeros(9,1); beta_time3_50_BKY=zeros(9,1); beta_time5_50_BKY=zeros(9,1); 
r_time1_50_BKY=zeros(9,1); r_time3_50_BKY=zeros(9,1); r_time5_50_BKY=zeros(9,1); 
beta_time1_50_BKY_q=zeros(33,1); beta_time3_50_BKY_q=zeros(33,1); beta_time5_50_BKY_q=zeros(33,1); 
r_time1_50_BKY_q=zeros(33,1); r_time3_50_BKY_q=zeros(33,1); r_time5_50_BKY_q=zeros(33,1); 


for i=1:9; 
    
beta_time1_50_BY(i,1)=quantile(beta_time1_BY(i,:),.5); 
beta_time3_50_BY(i,1)=quantile(beta_time3_BY(i,:),.5);
beta_time5_50_BY(i,1)=quantile(beta_time5_BY(i,:),.5);

r_time1_50_BY(i,1)=quantile(r_time1_BY(i,:),.5); 
r_time3_50_BY(i,1)=quantile(r_time3_BY(i,:),.5);
r_time5_50_BY(i,1)=quantile(r_time5_BY(i,:),.5);

beta_time1_50_BKY(i,1)=quantile(beta_time1_BKY(i,:),.5); 
beta_time3_50_BKY(i,1)=quantile(beta_time3_BKY(i,:),.5);
beta_time5_50_BKY(i,1)=quantile(beta_time5_BKY(i,:),.5);

r_time1_50_BKY(i,1)=quantile(r_time1_BKY(i,:),.5); 
r_time3_50_BKY(i,1)=quantile(r_time3_BKY(i,:),.5);
r_time5_50_BKY(i,1)=quantile(r_time5_BKY(i,:),.5);
    
end; 

for i=1:33; 
   
beta_time1_50_BY_q(i,1)=quantile(beta_time1_q_BY(i,:),.5); 
beta_time3_50_BY_q(i,1)=quantile(beta_time3_q_BY(i,:),.5);
beta_time5_50_BY_q(i,1)=quantile(beta_time5_q_BY(i,:),.5);

r_time1_50_BY_q(i,1)=quantile(r_time1_q_BY(i,:),.5); 
r_time3_50_BY_q(i,1)=quantile(r_time3_q_BY(i,:),.5);
r_time5_50_BY_q(i,1)=quantile(r_time5_q_BY(i,:),.5);

beta_time1_50_BKY_q(i,1)=quantile(beta_time1_q_BKY(i,:),.5); 
beta_time3_50_BKY_q(i,1)=quantile(beta_time3_q_BKY(i,:),.5);
beta_time5_50_BKY_q(i,1)=quantile(beta_time5_q_BKY(i,:),.5);

r_time1_50_BKY_q(i,1)=quantile(r_time1_q_BKY(i,:),.5); 
r_time3_50_BKY_q(i,1)=quantile(r_time3_q_BKY(i,:),.5);
r_time5_50_BKY_q(i,1)=quantile(r_time5_q_BKY(i,:),.5);
    
end; 


% Volatility Censoring Experiment 

Censor_vector=zeros(4,1); 

% Percentage of Yearly Samples with any censoring
Censor_vector(1,1)=mean(Indicator_yBY);Censor_vector(2,1)= mean(Indicator_yBKY); 
% Percentage of total time censored +12 because 12 extra months needed for
% growth rates 
Censor_vector(3,1)=mean(numcens_yBY)/(yearly_months+12); Censor_vector(4,1)=mean(numcens_yBKY)/(yearly_months+12); 


% Average Results for BKY model with or without throwing out censored
% samples 

Throw_out=zeros(2,1); 

Throw_out(1,1)=quantile(reshape(cons_y_BKY(1,2,:),simnum,1,1).*Indicator_yBKY, (sum(1-Indicator_yBKY)+.5*(sum(Indicator_yBKY)))/simnum); 
Throw_out(2,1)=quantile(reshape(cons_y_BKY(1,2,:),simnum,1,1).*(1-Indicator_yBKY), (sum(Indicator_yBKY)+.5*(sum(1-Indicator_yBKY)))/simnum); 

% Great Depression Results
% BY Model 

GD_results_BY=zeros(4,1); 
GD_results_BY(1)=mean(GD_down_BY); 
GD_results_BY(2)=mean(GD_rec_BY);
GD_results_BY(3)=sum(GD_down_num_BY)/simnum; 
GD_results_BY(4)=sum(GD_rec_num_BY)/simnum; 

GD_results_BKY=zeros(4,1); 
GD_results_BKY(1)=mean(GD_down_BKY); 
GD_results_BKY(2)=mean(GD_rec_BKY);
GD_results_BKY(3)=sum(GD_down_num_BKY)/simnum; 
GD_results_BKY(4)=sum(GD_rec_num_BKY)/simnum; 


% Model With Channels Shut Down

no_vol_mom_BY=zeros(2,1); 
no_vol_mom_BKY=zeros(2,1); 
iid_mom_BY=zeros(2,1); 
iid_mom_BKY=zeros(2,1); 

for i=1:2; 
    
no_vol_mom_BY(i,1)=quantile(no_vol_BY(i,:),.5); 
no_vol_mom_BKY(i,1)=quantile(no_vol_BKY(i,:),.5);  
iid_mom_BY(i,1)=quantile(iid_model_BY(i,:),.5); 
iid_mom_BKY(i,1)=quantile(iid_model_BKY(i,:),.5);    
    
end; 






% Generate Table Output

% Table Order 1. Parameters 2. Moments 3. Variance Ratios 4. Predictability
% 5. Pred of Vol 6. Multi-Pred 7. TS 8. Mom and EIS 9. EIS est

% Appendix Tables 1. Autocorrelations 2. Pred Betas 3. Vol Betas 4. multi
% betas 



% Body Tables 


Table_2=[Med_mom_y_BY(:,1) Med_mom_y_BKY(:,1) moment_mat_y(:,1) Med_mom_q_BY(:,1) Med_mom_q_BKY(:,1) moment_mat_q(:,1) ;...
         Med_mom_y_BY(:,2) Med_mom_y_BKY(:,2) moment_mat_y(:,2) Med_mom_q_BY(:,2) Med_mom_q_BKY(:,2) moment_mat_q(:,2) ;...
         Med_mom_y_BY(:,3) Med_mom_y_BKY(:,3) moment_mat_y(:,3) Med_mom_q_BY(:,3) Med_mom_q_BKY(:,3) moment_mat_q(:,3) ;...
         Med_mom_y_BY(:,4) Med_mom_y_BKY(:,4) moment_mat_y(:,4) Med_mom_q_BY(:,4) Med_mom_q_BKY(:,4) moment_mat_q(:,4) ;...
         Med_mom_y_BY(:,5) Med_mom_y_BKY(:,5) moment_mat_y(:,5) Med_mom_q_BY(:,5) Med_mom_q_BKY(:,5) moment_mat_q(:,5)]; 

Table_3=[AVc(1,1) cons_VR_50_BY(1) cons_VR_50_BKY(1) cons_VR_perc_BY(1) cons_VR_perc_BKY(1) ; ...
    AVc(3,1) cons_VR_50_BY(3) cons_VR_50_BKY(3) cons_VR_perc_BY(3) cons_VR_perc_BKY(3) ; ...
    AVc(5,1) cons_VR_50_BY(5) cons_VR_50_BKY(5) cons_VR_perc_BY(5) cons_VR_perc_BKY(5);...
    AVc_q(1,1) cons_VR_50_BY_q(1) cons_VR_50_BKY_q(1) cons_VR_perc_BY_q(1) cons_VR_perc_BKY_q(1) ; ...
    AVc_q(3,1) cons_VR_50_BY_q(3) cons_VR_50_BKY_q(3) cons_VR_perc_BY_q(3) cons_VR_perc_BKY_q(3) ; ...
    AVc_q(5,1) cons_VR_50_BY_q(5) cons_VR_50_BKY_q(5) cons_VR_perc_BY_q(5) cons_VR_perc_BKY_q(5);...
    AVd(1,1) div_VR_50_BY(1) div_VR_50_BKY(1) div_VR_perc_BY(1) div_VR_perc_BKY(1);...
    AVd(3,1) div_VR_50_BY(3) div_VR_50_BKY(3) div_VR_perc_BY(3) div_VR_perc_BKY(3);...
    AVd(5,1) div_VR_50_BY(5) div_VR_50_BKY(5) div_VR_perc_BY(5) div_VR_perc_BKY(5);...
    AVd_q(1,1) div_VR_50_BY_q(1) div_VR_50_BKY_q(1) div_VR_perc_BY_q(1) div_VR_perc_BKY_q(1) ; ...
    AVd_q(3,1) div_VR_50_BY_q(3) div_VR_50_BKY_q(3) div_VR_perc_BY_q(3) div_VR_perc_BKY_q(3) ; ...
    AVd_q(5,1) div_VR_50_BY_q(5) div_VR_50_BKY_q(5) div_VR_perc_BY_q(5) div_VR_perc_BKY_q(5)]; 


Table_4=[predict_ret_y(:,1) predict_ret_y(:,2) predict_ret_y(:,3) Ret_50_BY_y_r Ret_50_BKY_y_r Ret_perc_BY_y_r Ret_perc_BKY_y_r ;...
         predict_ret_q(:,1) predict_ret_q(:,2) predict_ret_q(:,3) Ret_50_BY_q_r Ret_50_BKY_q_r Ret_perc_BY_q_r Ret_perc_BKY_q_r;...
         predict_cons_y(:,1) predict_cons_y(:,2) predict_cons_y(:,3) Cons_50_BY_y_r Cons_50_BKY_y_r Cons_perc_BY_y_r Cons_perc_BKY_y_r ;...
         predict_cons_q(:,1) predict_cons_q(:,2) predict_cons_q(:,3) Cons_50_BY_q_r Cons_50_BKY_q_r Cons_perc_BY_q_r Cons_perc_BKY_q_r ;...
         predict_div_y(:,1) predict_div_y(:,2) predict_div_y(:,3) Div_50_BY_y_r Div_50_BKY_y_r Div_perc_BY_y_r Div_perc_BKY_y_r ;...
         predict_div_q(:,1) predict_div_q(:,2) predict_div_q(:,3) Div_50_BY_q_r Div_50_BKY_q_r Div_perc_BY_q_r Div_perc_BKY_q_r]; 
     
Table_5=[predict_retv_y(:,1) predict_retv_y(:,2) predict_retv_y(:,3) vRet_50_BY_y_r vRet_50_BKY_y_r vRet_perc_BY_y_r vRet_perc_BKY_y_r ;...
         predict_retv_q(:,1) predict_retv_q(:,2) predict_retv_q(:,3) vRet_50_BY_q_r vRet_50_BKY_q_r vRet_perc_BY_q_r vRet_perc_BKY_q_r ;...
         predict_consv_y(:,1) predict_consv_y(:,2) predict_consv_y(:,3) vCons_50_BY_y_r vCons_50_BKY_y_r vCons_perc_BY_y_r vCons_perc_BKY_y_r;...
         predict_consv_q(:,1) predict_consv_q(:,2) predict_consv_q(:,3) vCons_50_BY_q_r vCons_50_BKY_q_r vCons_perc_BY_q_r vCons_perc_BKY_q_r ;...
         predict_divv_y(:,1) predict_divv_y(:,2) predict_divv_y(:,3) vDiv_50_BY_y_r vDiv_50_BKY_y_r vDiv_perc_BY_y_r vDiv_perc_BKY_y_r ;...
         predict_divv_q(:,1) predict_divv_q(:,2) predict_divv_q(:,3) vDiv_50_BY_q_r vDiv_50_BKY_q_r vDiv_perc_BY_q_r vDiv_perc_BKY_q_r]; 
     
Table_6=[predict_ret_y_mv(:,7) Ret_50_BY_y_r_mv Ret_50_BKY_y_r_mv Ret_perc_BY_y_r_mv Ret_perc_BKY_y_r_mv ;...
         predict_cons_y_mv(:,7) Cons_50_BY_y_r_mv Cons_50_BKY_y_r_mv Cons_perc_BY_y_r_mv Cons_perc_BKY_y_r_mv ;...
         predict_div_y_mv(:,7) Div_50_BY_y_r_mv Div_50_BKY_y_r_mv Div_perc_BY_y_r_mv Div_perc_BKY_y_r_mv;...
         predict_rf_y_mv(:,7) Rf_50_BY_y_r_mv Rf_50_BKY_y_r_mv Rf_perc_BY_y_r_mv Rf_perc_BKY_y_r_mv ];
     
Table_7=[TS_moments_BY; TS_moments_BKY]; 
 
Table_8=[est_rf rf_50_BY_y rf_50_BKY_y rf_perc_BY_y rf_perc_BKY_y;...
         est_rf_q rf_50_BY_q rf_50_BKY_q rf_perc_BY_q rf_perc_BKY_q; ...
         est_ret re_50_BY_y re_50_BKY_y re_perc_BY_y re_perc_BKY_y;...
         est_ret_q re_50_BY_q re_50_BKY_q re_perc_BY_q re_perc_BKY_q; ...
         est_rf_inv rf_inv_50_BY_y rf_inv_50_BKY_y rf_inv_perc_BY_y rf_inv_perc_BKY_y;...
         est_rf_inv_q rf_inv_50_BY_q rf_inv_50_BKY_q rf_inv_perc_BY_q rf_inv_perc_BKY_q; ...
         est_ret_inv re_inv_50_BY_y re_inv_50_BKY_y re_inv_perc_BY_y re_inv_perc_BKY_y;...
         est_ret_inv_q re_inv_50_BY_q re_inv_50_BKY_q re_inv_perc_BY_q re_inv_perc_BKY_q]; 
      

% Appendix Tables 

Table_1_app=[AC_y(:,1) AC_cons_50_BY AC_cons_50_BKY AC_cons_perc_BY AC_cons_perc_BKY ; ...
    AC_q(:,1) AC_cons_50_BY_q AC_cons_50_BKY_q AC_cons_perc_BY_q AC_cons_perc_BKY_q ; ...
    AC_y(:,2) AC_div_50_BY AC_div_50_BKY AC_div_perc_BY AC_div_perc_BKY;...
    AC_q(:,2) AC_div_50_BY_q AC_div_50_BKY_q AC_div_perc_BY_q AC_div_perc_BKY_q]; 

Table_2_app=[predict_ret_y(:,1) Ret_50_BY_y_b Ret_50_BKY_y_b Ret_perc_BY_y_b Ret_perc_BKY_y_b ;...
         predict_ret_q(:,1) Ret_50_BY_q_b Ret_50_BKY_q_b Ret_perc_BY_q_b Ret_perc_BKY_q_b;...
         predict_cons_y(:,1) Cons_50_BY_y_b Cons_50_BKY_y_b Cons_perc_BY_y_b Cons_perc_BKY_y_b ;...
         predict_cons_q(:,1) Cons_50_BY_q_b Cons_50_BKY_q_b Cons_perc_BY_q_b Cons_perc_BKY_q_b ;...
         predict_div_y(:,1) Div_50_BY_y_b Div_50_BKY_y_b Div_perc_BY_y_b Div_perc_BKY_y_b ;...
         predict_div_q(:,1) Div_50_BY_q_b Div_50_BKY_q_b Div_perc_BY_q_b Div_perc_BKY_q_b]; 

Table_3_app=[predict_retv_y(:,1) vRet_50_BY_y_b vRet_50_BKY_y_b vRet_perc_BY_y_b vRet_perc_BKY_y_b ;...
         predict_retv_q(:,1) vRet_50_BY_q_b vRet_50_BKY_q_b vRet_perc_BY_q_b vRet_perc_BKY_q_b ;...
         predict_consv_y(:,1) vCons_50_BY_y_b vCons_50_BKY_y_b vCons_perc_BY_y_b vCons_perc_BKY_y_b;...
         predict_consv_q(:,1) vCons_50_BY_q_b vCons_50_BKY_q_b vCons_perc_BY_q_b vCons_perc_BKY_q_b ;...
         predict_divv_y(:,1) vDiv_50_BY_y_b vDiv_50_BKY_y_b vDiv_perc_BY_y_b vDiv_perc_BKY_y_b ;...
         predict_divv_q(:,1) vDiv_50_BY_q_b vDiv_50_BKY_q_b vDiv_perc_BY_q_b vDiv_perc_BKY_q_b]; 

Table_4a_app=[predict_ret_y_mv(1,1) predict_ret_y_mv(1,2) predict_ret_y_mv(1,3) predict_cons_y_mv(1,1) predict_cons_y_mv(1,2) predict_cons_y_mv(1,3); ...
    ret_ret_mv_50_BY(1) ret_pd_mv_50_BY(1) ret_rf_mv_50_BY(1) cons_cons_mv_50_BY(1) cons_pd_mv_50_BY(1) cons_rf_mv_50_BY(1);...
    ret_ret_mv_perc_BY(1) ret_pd_mv_perc_BY(1) ret_rf_mv_perc_BY(1) cons_cons_mv_perc_BY(1) cons_pd_mv_perc_BY(1) cons_rf_mv_perc_BY(1);...
    predict_ret_y_mv(2,1) predict_ret_y_mv(2,2) predict_ret_y_mv(2,3) predict_cons_y_mv(2,1) predict_cons_y_mv(2,2) predict_cons_y_mv(2,3); ...
    ret_ret_mv_50_BY(2) ret_pd_mv_50_BY(2) ret_rf_mv_50_BY(2) cons_cons_mv_50_BY(2) cons_pd_mv_50_BY(2) cons_rf_mv_50_BY(2);...
    ret_ret_mv_perc_BY(2) ret_pd_mv_perc_BY(2) ret_rf_mv_perc_BY(2) cons_cons_mv_perc_BY(2) cons_pd_mv_perc_BY(2) cons_rf_mv_perc_BY(2);...
    predict_ret_y_mv(3,1) predict_ret_y_mv(3,2) predict_ret_y_mv(3,3) predict_cons_y_mv(3,1) predict_cons_y_mv(3,2) predict_cons_y_mv(3,3); ...
    ret_ret_mv_50_BY(3) ret_pd_mv_50_BY(3) ret_rf_mv_50_BY(3) cons_cons_mv_50_BY(3) cons_pd_mv_50_BY(3) cons_rf_mv_50_BY(3);...
    ret_ret_mv_perc_BY(3) ret_pd_mv_perc_BY(3) ret_rf_mv_perc_BY(3) cons_cons_mv_perc_BY(3) cons_pd_mv_perc_BY(3) cons_rf_mv_perc_BY(3);...
    predict_div_y_mv(1,1) predict_div_y_mv(1,2) predict_div_y_mv(1,3) predict_rf_y_mv(1,1) predict_rf_y_mv(1,2) predict_rf_y_mv(1,3); ...
    div_div_mv_50_BY(1) div_pd_mv_50_BY(1) div_rf_mv_50_BY(1) rf_cons_mv_50_BY(1) rf_pd_mv_50_BY(1) rf_rf_mv_50_BY(1);...
    div_div_mv_perc_BY(1) div_pd_mv_perc_BY(1) div_rf_mv_perc_BY(1) rf_cons_mv_perc_BY(1) rf_pd_mv_perc_BY(1) rf_rf_mv_perc_BY(1);...
    predict_div_y_mv(2,1) predict_div_y_mv(2,2) predict_div_y_mv(2,3) predict_rf_y_mv(2,1) predict_rf_y_mv(2,2) predict_rf_y_mv(2,3); ...
    div_div_mv_50_BY(2) div_pd_mv_50_BY(2) div_rf_mv_50_BY(2) rf_cons_mv_50_BY(2) rf_pd_mv_50_BY(2) rf_rf_mv_50_BY(2);...
    div_div_mv_perc_BY(2) div_pd_mv_perc_BY(2) div_rf_mv_perc_BY(2) rf_cons_mv_perc_BY(2) rf_pd_mv_perc_BY(2) rf_rf_mv_perc_BY(2);...
    predict_div_y_mv(3,1) predict_div_y_mv(3,2) predict_div_y_mv(3,3) predict_rf_y_mv(3,1) predict_rf_y_mv(3,2) predict_rf_y_mv(3,3); ...
    div_div_mv_50_BY(3) div_pd_mv_50_BY(3) div_rf_mv_50_BY(3) rf_cons_mv_50_BY(3) rf_pd_mv_50_BY(3) rf_rf_mv_50_BY(3);...
    div_div_mv_perc_BY(3) div_pd_mv_perc_BY(3) div_rf_mv_perc_BY(3) rf_cons_mv_perc_BY(3) rf_pd_mv_perc_BY(3) rf_rf_mv_perc_BY(3)]; 

Table_4b_app=[predict_ret_y_mv(1,1) predict_ret_y_mv(1,2) predict_ret_y_mv(1,3) predict_cons_y_mv(1,1) predict_cons_y_mv(1,2) predict_cons_y_mv(1,3); ...
    ret_ret_mv_50_BKY(1) ret_pd_mv_50_BKY(1) ret_rf_mv_50_BKY(1) cons_cons_mv_50_BKY(1) cons_pd_mv_50_BKY(1) cons_rf_mv_50_BKY(1);...
    ret_ret_mv_perc_BKY(1) ret_pd_mv_perc_BKY(1) ret_rf_mv_perc_BKY(1) cons_cons_mv_perc_BKY(1) cons_pd_mv_perc_BKY(1) cons_rf_mv_perc_BKY(1);...
    predict_ret_y_mv(2,1) predict_ret_y_mv(2,2) predict_ret_y_mv(2,3) predict_cons_y_mv(2,1) predict_cons_y_mv(2,2) predict_cons_y_mv(2,3); ...
    ret_ret_mv_50_BKY(2) ret_pd_mv_50_BKY(2) ret_rf_mv_50_BKY(2) cons_cons_mv_50_BKY(2) cons_pd_mv_50_BKY(2) cons_rf_mv_50_BKY(2);...
    ret_ret_mv_perc_BKY(2) ret_pd_mv_perc_BKY(2) ret_rf_mv_perc_BKY(2) cons_cons_mv_perc_BKY(2) cons_pd_mv_perc_BKY(2) cons_rf_mv_perc_BKY(2);...
    predict_ret_y_mv(3,1) predict_ret_y_mv(3,2) predict_ret_y_mv(3,3) predict_cons_y_mv(3,1) predict_cons_y_mv(3,2) predict_cons_y_mv(3,3); ...
    ret_ret_mv_50_BKY(3) ret_pd_mv_50_BKY(3) ret_rf_mv_50_BKY(3) cons_cons_mv_50_BKY(3) cons_pd_mv_50_BKY(3) cons_rf_mv_50_BKY(3);...
    ret_ret_mv_perc_BKY(3) ret_pd_mv_perc_BKY(3) ret_rf_mv_perc_BKY(3) cons_cons_mv_perc_BKY(3) cons_pd_mv_perc_BKY(3) cons_rf_mv_perc_BKY(3);...
    predict_div_y_mv(1,1) predict_div_y_mv(1,2) predict_div_y_mv(1,3) predict_rf_y_mv(1,1) predict_rf_y_mv(1,2) predict_rf_y_mv(1,3); ...
    div_div_mv_50_BKY(1) div_pd_mv_50_BKY(1) div_rf_mv_50_BKY(1) rf_cons_mv_50_BKY(1) rf_pd_mv_50_BKY(1) rf_rf_mv_50_BKY(1);...
    div_div_mv_perc_BKY(1) div_pd_mv_perc_BKY(1) div_rf_mv_perc_BKY(1) rf_cons_mv_perc_BKY(1) rf_pd_mv_perc_BKY(1) rf_rf_mv_perc_BKY(1);...
    predict_div_y_mv(2,1) predict_div_y_mv(2,2) predict_div_y_mv(2,3) predict_rf_y_mv(2,1) predict_rf_y_mv(2,2) predict_rf_y_mv(2,3); ...
    div_div_mv_50_BKY(2) div_pd_mv_50_BKY(2) div_rf_mv_50_BKY(2) rf_cons_mv_50_BKY(2) rf_pd_mv_50_BKY(2) rf_rf_mv_50_BKY(2);...
    div_div_mv_perc_BKY(2) div_pd_mv_perc_BKY(2) div_rf_mv_perc_BKY(2) rf_cons_mv_perc_BKY(2) rf_pd_mv_perc_BKY(2) rf_rf_mv_perc_BKY(2);...
    predict_div_y_mv(3,1) predict_div_y_mv(3,2) predict_div_y_mv(3,3) predict_rf_y_mv(3,1) predict_rf_y_mv(3,2) predict_rf_y_mv(3,3); ...
    div_div_mv_50_BKY(3) div_pd_mv_50_BKY(3) div_rf_mv_50_BKY(3) rf_cons_mv_50_BKY(3) rf_pd_mv_50_BKY(3) rf_rf_mv_50_BKY(3);...
    div_div_mv_perc_BKY(3) div_pd_mv_perc_BKY(3) div_rf_mv_perc_BKY(3) rf_cons_mv_perc_BKY(3) rf_pd_mv_perc_BKY(3) rf_rf_mv_perc_BKY(3)]; 

Table_5_app=[100*mean(rf) Med_mom_y_BY(1,4) low_EIS_med_BY(1) Med_mom_y_BKY(1,4) low_EIS_med_BKY(1);...
         100*std(rf) Med_mom_y_BY(2,4) low_EIS_med_BY(2) Med_mom_y_BKY(2,4) low_EIS_med_BKY(2); ...
     100*(mean(exret)+.5*var(exret)) Med_mom_y_BY(1,6) low_EIS_med_BY(3) Med_mom_y_BKY(1,6) low_EIS_med_BKY(3); ...
     100*std(exret) Med_mom_y_BY(2,6) low_EIS_med_BY(4) Med_mom_y_BKY(2,6) low_EIS_med_BKY(4);...
     mean(pd) Med_mom_y_BY(1,5) low_EIS_med_BY(5) Med_mom_y_BKY(1,5) low_EIS_med_BKY(5);...
     std(pd) Med_mom_y_BY(2,5) low_EIS_med_BY(6) Med_mom_y_BKY(2,5) low_EIS_med_BKY(6)];

Table_6_app=[est_rf_full rf_50_BY_y_full rf_50_BKY_y_full rf_perc_BY_y_full rf_perc_BKY_y_full;...
         est_rf_q_full rf_50_BY_q_full rf_50_BKY_q_full rf_perc_BY_q_full rf_perc_BKY_q_full; ...
         est_ret_full re_50_BY_y_full re_50_BKY_y_full re_perc_BY_y_full re_perc_BKY_y_full;...
         est_ret_q_full re_50_BY_q_full re_50_BKY_q_full re_perc_BY_q_full re_perc_BKY_q_full; ...
         est_rf_inv_full rf_inv_50_BY_y_full rf_inv_50_BKY_y_full rf_inv_perc_BY_y_full rf_inv_perc_BKY_y_full;...
         est_rf_inv_q_full rf_inv_50_BY_q_full rf_inv_50_BKY_q_full rf_inv_perc_BY_q_full rf_inv_perc_BKY_q_full; ...
         est_ret_inv_full re_inv_50_BY_y_full re_inv_50_BKY_y_full re_inv_perc_BY_y_full re_inv_perc_BKY_y_full;...
         est_ret_inv_q_full re_inv_50_BY_q_full re_inv_50_BKY_q_full re_inv_perc_BY_q_full re_inv_perc_BKY_q_full]; 
     

% Save Tables 

save Table2.txt Table_2 -ascii
save Table3.txt Table_3 -ascii
save Table4.txt Table_4 -ascii
save Table5.txt Table_5 -ascii
save Table6.txt Table_6 -ascii
save Table7.txt Table_7 -ascii
save Table8.txt Table_8 -ascii

save Table1app.txt Table_1_app -ascii
save Table2app.txt Table_2_app -ascii
save Table3app.txt Table_3_app -ascii
save Table4aapp.txt Table_4a_app -ascii
save Table4bapp.txt Table_4b_app -ascii
save Table5app.txt Table_5_app -ascii
save Table6app.txt Table_6_app -ascii




% Output Results for Figures 

line=[0 -10; 0 10]; 
zerosv=[-40 0; 40 0]; 
vertline=[1 -100;1 100]; 
ytime=-4:1:4; 
qtime=-16:1:16; 



    

% Yearly Coefficient
plot (ytime, beta_time1_50_BY, '-k', ytime, beta_time1_50_BKY,'--k',ytime,beta_time1,':k',zerosv(:,1),zerosv(:,2),'k',vertline(:,1),vertline(:,2),'k','LineWidth',2)
ylabel ('Beta','FontSize',15); 
xlabel ('j','FontSize',15); 
axis([-4 4 -.02 .1]); 
title ('K=1 Beta','FontSize',15); 
saveas(gcf, 'BYbeta1.bmp'); 


plot (ytime, beta_time3_50_BY, '-k', ytime, beta_time3_50_BKY,'--k',ytime,beta_time3,':k',zerosv(:,1),zerosv(:,2),'k',vertline(:,1),vertline(:,2),'k','LineWidth',2)
ylabel ('Beta','FontSize',15); 
xlabel ('j','FontSize',15); 
axis([-4 4 -.02 .25]);
title ('K=3 Beta','FontSize',15); 
saveas(gcf, 'BYbeta3.bmp');

plot (ytime, beta_time5_50_BY, '-k', ytime, beta_time5_50_BKY,'--k',ytime,beta_time5,':k',zerosv(:,1),zerosv(:,2),'k',vertline(:,1),vertline(:,2),'k','LineWidth',2)
ylabel ('Beta','FontSize',15); 
xlabel ('j','FontSize',15); 
axis([-4 4 -.02 .4]); 
title ('K=5 Beta'); 
saveas(gcf, 'BYbeta5.bmp');


% Yearly R-squared
plot (ytime, r_time1_50_BY, '-k', ytime, r_time1_50_BKY,'--k',ytime,r_time1,':k',zerosv(:,1),zerosv(:,2),'k',vertline(:,1),vertline(:,2),'k','LineWidth',2)
ylabel ('R-squared','FontSize',15); 
xlabel ('j','FontSize',15); 
axis([-4 4 0 .35]); 
title ('K=1 R-squared','FontSize',15); 
saveas(gcf, 'BYr1.bmp'); 

plot (ytime, r_time3_50_BY, '-k', ytime, r_time3_50_BKY,'--k',ytime,r_time3,':k',zerosv(:,1),zerosv(:,2),'k',vertline(:,1),vertline(:,2),'k','LineWidth',2)
ylabel ('R-squared','FontSize',15); 
xlabel ('j','FontSize',15);  
axis([-4 4 0 .5]); 
title ('K=3 R-squared','FontSize',15); 
saveas(gcf, 'BYr3.bmp'); 


plot (ytime, r_time5_50_BY, '-k', ytime, r_time5_50_BKY,'--k',ytime,r_time5,':k',zerosv(:,1),zerosv(:,2),'k',vertline(:,1),vertline(:,2),'k','LineWidth',2)
ylabel ('R-squared','FontSize',15); 
xlabel ('j','FontSize',15); 
axis([-4 4 0 .5]); 
title ('K=5 R-squared','FontSize',15); 
saveas(gcf, 'BYr5.bmp'); 



% Quarterly Coefficients


plot (qtime, beta_time1_50_BY_q, '-k', qtime, beta_time1_50_BKY_q,'--k',qtime,beta_time1_q,':k',zerosv(:,1),zerosv(:,2),'k',vertline(:,1),vertline(:,2),'k','LineWidth',2)
ylabel ('Beta'); 
xlabel ('j'); 
axis([-16 16 -.02 .1]); 
title ('K=4 Beta'); 
saveas(gcf, 'BYbetaq1.bmp'); 

plot (qtime, beta_time3_50_BY_q, '-k', qtime, beta_time3_50_BKY_q,'--k',qtime,beta_time3_q,':k',zerosv(:,1),zerosv(:,2),'k',vertline(:,1),vertline(:,2),'k','LineWidth',2)
ylabel ('Beta'); 
xlabel ('j'); 
axis([-16 16 -.02 .25]); 
title ('K=12 Beta'); 
saveas(gcf, 'BYbetaq3.bmp');

plot (qtime, beta_time5_50_BY_q, '-k', qtime,beta_time5_50_BKY_q,'--k',qtime,beta_time5_q,':k',zerosv(:,1),zerosv(:,2),'k',vertline(:,1),vertline(:,2),'k','LineWidth',2)
ylabel ('Beta'); 
xlabel ('j'); 
axis([-16 16 -.02 .4]); 
title ('K=20 Beta'); 
saveas(gcf, 'BYbetaq5.bmp');


% Quarterly R-squared

plot (qtime, r_time1_50_BY_q, '-k', qtime, r_time1_50_BKY_q,'--k',qtime,r_time1_q,':k',zerosv(:,1),zerosv(:,2),'k',vertline(:,1),vertline(:,2),'k','LineWidth',2)
ylabel ('R-squared');
xlabel ('j'); 
axis([-16 16 0 .3]); 
title ('K=4 R-squared'); 
saveas(gcf, 'BYrq1.bmp'); 

plot (qtime, r_time3_50_BY_q, '-k', qtime,r_time3_50_BKY_q,'--k',qtime,r_time3_q,':k',zerosv(:,1),zerosv(:,2),'k',vertline(:,1),vertline(:,2),'k','LineWidth',2)
ylabel ('R-squared'); 
xlabel ('j'); 
axis([-16 16 0 .5]); 
title ('K=12 R-squared'); 
saveas(gcf, 'BYrq3.bmp'); 


plot (qtime, r_time5_50_BY_q, '-k', qtime, r_time5_50_BKY_q,'--k',qtime,r_time5_q,':k',zerosv(:,1),zerosv(:,2),'k',vertline(:,1),vertline(:,2),'k','LineWidth',2)
ylabel ('R-squared'); 
xlabel ('j');  
axis([-16 16 0 .5]); 
title ('K=20 R-squared'); 
saveas(gcf, 'BYrq5.bmp'); 









